@@ -174,10 +174,10 @@ bool BasicFileLauncher::launchWithApp(GAppInfo* app, const FilePathList& paths,
         auto uri = path.uri();
         uris = g_list_prepend(uris, uri.release());
     }
+    uris = g_list_reverse(uris);
     GErrorPtr err;
     bool ret = bool(g_app_info_launch_uris(app, uris, ctx, &err));
-    g_list_foreach(uris, reinterpret_cast<GFunc>(g_free), nullptr);
-    g_list_free(uris);
+    g_list_free_full(uris, g_free);
     if(!ret) {
         // FIXME: show error for all files
         showError(ctx, err, paths.empty() ? FilePath{} : paths[0]);
@@ -206,8 +206,11 @@ bool BasicFileLauncher::launchDesktopEntry(const FileInfoPtr &fileInfo, const Fi
             else {
                 if(target.empty()) {
                     filename = fileInfo->path().localPath();
+                    desktopEntryName = filename.get();
+                }
+                else {
+                    desktopEntryName = target.c_str();
                 }
-                desktopEntryName = !target.empty() ? target.c_str() : filename.get();
             }
             break;
         }
@@ -224,8 +227,11 @@ bool BasicFileLauncher::launchDesktopEntry(const FileInfoPtr &fileInfo, const Fi
             fileInfo->path().hasUriScheme("menu")) {
         if(target.empty()) {
             filename = fileInfo->path().localPath();
+            desktopEntryName = filename.get();
+        }
+        else {
+            desktopEntryName = target.c_str();
         }
-        desktopEntryName = !target.empty() ? target.c_str() : filename.get();
     }
 
     if(desktopEntryName) {
@@ -259,19 +265,30 @@ bool BasicFileLauncher::launchDesktopEntry(const char *desktopEntryName, const F
             auto uri = path.uri();
             uris = g_list_prepend(uris, uri.release());
         }
+        uris = g_list_reverse(uris);
         GErrorPtr err;
         ret = bool(fm_app_info_launch(app, uris, ctx, &err));
-        g_list_foreach(uris, reinterpret_cast<GFunc>(g_free), nullptr);
-        g_list_free(uris);
+        g_list_free_full(uris, g_free);
         if(!ret) {
             // FIXME: show error for all files
             showError(ctx, err, paths.empty() ? FilePath{} : paths[0]);
         }
     }
     else {
-        QString msg = QObject::tr("Invalid desktop entry file: '%1'").arg(desktopEntryName);
-        GErrorPtr err{G_IO_ERROR, G_IO_ERROR_FAILED, msg};
-        showError(ctx, err);
+        // if no desktop app is found but we have a uri scheme, try to launch it directly
+        auto scheme = CStrPtr{g_uri_parse_scheme(desktopEntryName)};
+        if (scheme) {
+            if(GAppInfoPtr app{g_app_info_get_default_for_uri_scheme(scheme.get()), false}) {
+                FilePathList uris{FilePath::fromUri(desktopEntryName)};
+                launchWithApp(app.get(), uris, ctx);
+                ret = true;
+            }
+        }
+        if (!ret) {
+            QString msg = QObject::tr("Invalid desktop entry file: '%1'").arg(QString::fromUtf8(desktopEntryName));
+            GErrorPtr err{G_IO_ERROR, G_IO_ERROR_FAILED, msg};
+            showError(ctx, err);
+        }
     }
     return ret;
 }
@@ -305,7 +322,7 @@ FilePath BasicFileLauncher::handleShortcut(const FileInfoPtr& fileInfo, GAppLaun
             else {
                 GErrorPtr err{G_IO_ERROR, G_IO_ERROR_FAILED,
                               QObject::tr("No default application is set to launch '%1'")
-                              .arg(target.c_str())};
+                              .arg(QString::fromUtf8(target.c_str()))};
                 showError(nullptr, err);
             }
         }
@@ -345,7 +362,8 @@ bool BasicFileLauncher::launchExecutable(const FileInfoPtr &fileInfo, GAppLaunch
                     if(chdir(run_path.get()) != 0) {
                         cwd.reset();
                         // show errors
-                        QString msg = QObject::tr("Cannot set working directory to '%1': %2").arg(run_path.get()).arg(g_strerror(errno));
+                        QString msg = QObject::tr("Cannot set working directory to '%1': %2").arg(QString::fromUtf8(run_path.get()),
+                                                                                                  QString::fromUtf8(g_strerror(errno)));
                         GErrorPtr err{G_IO_ERROR, g_io_error_from_errno(errno), msg};
                         showError(ctx, err);
                     }
