@@ -30,7 +30,9 @@ _retry:
         false
     };
     if(!dir_inf) {
-        ErrorAction act = emitError(err, ErrorSeverity::MODERATE);
+        ErrorAction act = emitError(err, err.domain() == G_IO_ERROR && err.code() == G_IO_ERROR_CANCELLED
+                                         ? ErrorSeverity::MILD // may happen with MTP
+                                         : ErrorSeverity::MODERATE);
         if(act == ErrorAction::RETRY) {
             err.reset();
             goto _retry;
@@ -43,7 +45,7 @@ _retry:
         err = GErrorPtr{
                 G_IO_ERROR,
                 G_IO_ERROR_NOT_DIRECTORY,
-                tr("The specified directory '%1' is not valid").arg(path_str.get())
+                tr("The specified directory '%1' is not valid").arg(QString::fromUtf8(path_str.get()))
         };
         emitError(err, ErrorSeverity::CRITICAL);
         return;
