@@ -10,6 +10,7 @@ const char defaultGFileInfoQueryAttribs[] = "standard::*,"
                                             "unix::*,"
                                             "time::*,"
                                             "access::*,"
+                                            "trash::deletion-date,"
                                             "id::filesystem,"
                                             "metadata::emblems,"
                                             METADATA_TRUST;
@@ -41,7 +42,7 @@ void FileInfo::setFromGFileInfo(const GObjectPtr<GFileInfo>& inf, const FilePath
     if (const char * name = g_file_info_get_name(inf.get()))
         name_ = name;
 
-    dispName_ = g_file_info_get_display_name(inf.get());
+    dispName_ = QString::fromUtf8(g_file_info_get_display_name(inf.get()));
 
     size_ = g_file_info_get_size(inf.get());
 
@@ -261,6 +262,12 @@ _file_is_symlink:
     mtime_ = g_file_info_get_attribute_uint64(inf.get(), G_FILE_ATTRIBUTE_TIME_MODIFIED);
     atime_ = g_file_info_get_attribute_uint64(inf.get(), G_FILE_ATTRIBUTE_TIME_ACCESS);
     ctime_ = g_file_info_get_attribute_uint64(inf.get(), G_FILE_ATTRIBUTE_TIME_CHANGED);
+    if(auto dt = g_file_info_get_deletion_date(inf.get())){
+        dtime_ = g_date_time_to_unix(dt);
+    }
+    else {
+        dtime_ = 0;
+    }
     isHidden_ = g_file_info_get_is_hidden(inf.get());
     // g_file_info_get_is_backup() does not cover ".bak" and ".old".
     // NOTE: Here, dispName_ is not modified for desktop entries yet.
@@ -297,7 +304,7 @@ _file_is_symlink:
             /* Use title of the desktop entry for display */
             CStrPtr displayName{g_key_file_get_locale_string(kf, "Desktop Entry", "Name", nullptr, nullptr)};
             if(displayName) {
-                dispName_ = displayName.get();
+                dispName_ = QString::fromUtf8(displayName.get());
             }
             /* handle 'Hidden' key to set hidden attribute */
             if(!isHidden_) {
@@ -398,8 +405,9 @@ bool FileInfo::isTrustable() const {
                 return (strcmp(data, "true") == 0);
             }
         }
+        return false;
     }
-    return false;
+    return true;
 }
 
 void FileInfo::setTrustable(bool trust) const {
