@@ -22,7 +22,7 @@
  */
 
 #include "folder.h"
-#include <string.h>
+#include <cstring>
 #include <cassert>
 #include <QTimer>
 #include <QDebug>
@@ -44,7 +44,7 @@ Folder::Folder():
     fsInfoJob_{nullptr},
     volumeManager_{VolumeManager::globalInstance()},
     /* for file monitor */
-    has_idle_reload_handler{0},
+    has_idle_reload_handler{false},
     has_idle_update_handler{false},
     pending_change_notify{false},
     filesystem_info_pending{false},
@@ -112,6 +112,20 @@ std::shared_ptr<Folder> Folder::fromPath(const FilePath& path) {
     return folder;
 }
 
+// static
+// Checks if this is the path of a folder in use.
+std::shared_ptr<Folder> Folder::findByPath(const FilePath& path) {
+    std::lock_guard<std::mutex> lock{mutex_};
+    auto it = cache_.find(path);
+    if(it != cache_.end()) {
+        auto folder = it->second.lock();
+        if(folder) {
+            return folder;
+        }
+    }
+    return nullptr;
+}
+
 bool Folder::makeDirectory(const char* /*name*/, GError** /*error*/) {
     // TODO:
     // FIXME: what the API is used for in the original libfm C API?
@@ -142,6 +156,10 @@ bool Folder::isEmpty() const {
     return files_.empty();
 }
 
+bool Folder::hasFileMonitor() const {
+    return (dirMonitor_ != nullptr);
+}
+
 FileInfoList Folder::files() const {
     FileInfoList ret;
     ret.reserve(files_.size());
@@ -210,16 +228,6 @@ void Folder::onFileInfoFinished() {
         return;
     }
 
-    // process the changes accumulated during this info job
-    if(filesystem_info_pending // means a pending change; see "onFileSystemInfoFinished()"
-       || !paths_to_update.empty() || !paths_to_add.empty() || !paths_to_del.empty()) {
-        QTimer::singleShot(0, this, &Folder::processPendingChanges);
-    }
-    // there's no pending change at the moment; let the next one be processed
-    else {
-        has_idle_update_handler = false;
-    }
-
     FileInfoList files_to_add;
     FileInfoList files_to_delete;
     std::vector<FileInfoPair> files_to_update;
@@ -253,6 +261,16 @@ void Folder::onFileInfoFinished() {
         Q_EMIT filesChanged(files_to_update);
     }
     Q_EMIT contentChanged();
+
+    // process the changes accumulated during this info job
+    if(filesystem_info_pending // means a pending change; see "onFileSystemInfoFinished()"
+       || !paths_to_update.empty() || !paths_to_add.empty() || !paths_to_del.empty()) {
+        QTimer::singleShot(0, this, &Folder::processPendingChanges);
+    }
+    // there's no pending change at the moment; let the next one be processed
+    else {
+        has_idle_update_handler = false;
+    }
 }
 
 void Folder::processPendingChanges() {
@@ -296,21 +314,24 @@ void Folder::processPendingChanges() {
     }
 
     // process deletion
-    if(!paths_to_del.empty()) {
-        FileInfoList deleted_files;
-        for(const auto &path: paths_to_del) {
-            auto name = path.baseName();
-            auto it = files_.find(name.get());
-            if(it != files_.end()) {
-                deleted_files.push_back(it->second);
-                files_.erase(it);
-            }
+    FileInfoList deleted_files;
+    auto path_it = paths_to_del.begin();
+    while(path_it != paths_to_del.end()) {
+        const auto& path = *path_it;
+        auto name = path.baseName();
+        auto it = files_.find(name.get());
+        if(it != files_.end()) {
+            deleted_files.push_back(it->second);
+            files_.erase(it);
+            path_it = paths_to_del.erase(path_it);
         }
-        if(!deleted_files.empty()) {
-            Q_EMIT filesRemoved(deleted_files);
-            Q_EMIT contentChanged();
+        else {
+            ++path_it;
         }
-        paths_to_del.clear();
+    }
+    if(!deleted_files.empty()) {
+        Q_EMIT filesRemoved(deleted_files);
+        Q_EMIT contentChanged();
     }
 
     if(pending_change_notify) {
@@ -386,13 +407,12 @@ void Folder::eventFileDeleted(const FilePath& path) {
     bool deleted = true;
     // qDebug() << "delete " << path.baseName().get();
     // G_LOCK(lists);
-    if(std::find(paths_to_add.cbegin(), paths_to_add.cend(), path) != paths_to_add.cend()) {
-        // if the file was going to be added, just remove it from the addition queue
-        paths_to_add.erase(std::remove(paths_to_add.begin(), paths_to_add.end(), path), paths_to_add.cend());
-    }
-    else if(std::find(paths_to_del.cbegin(), paths_to_del.cend(), path) == paths_to_del.cend()) {
+    /* WARNING: If the file is in the addition queue, we shouldn not remove it from that queue
+       and ignore its deletion because it may have been added by the directory list job, in
+       which case, ignoring an addition-deletion sequence would result in a nonexistent file. */
+    if(std::find(paths_to_del.cbegin(), paths_to_del.cend(), path) == paths_to_del.cend()) {
         paths_to_del.push_back(path);
-        // the update queue should be cancelled for a file that is going to be deleted
+        // the update queue can be cancelled for a file that is going to be deleted
         paths_to_update.erase(std::remove(paths_to_update.begin(), paths_to_update.end(), path), paths_to_update.cend());
     }
     else {
@@ -481,28 +501,50 @@ void Folder::onFileChangeEvents(GFileMonitor* /*monitor*/, GFile* gf, GFile* /*o
     }
 }
 
+void Folder::setCutFiles(const std::shared_ptr<const HashSet>& cutFilesHashSet) {
+    if(cutFilesHashSet_ && !cutFilesHashSet_->empty()) {
+        lastCutFilesDirPath_ = cutFilesDirPath_;
+    }
+    cutFilesDirPath_ = QString::fromUtf8(dirPath_.toString().get());
+    cutFilesHashSet_ = cutFilesHashSet;
+}
+
+// checks whether there are cut files here
+bool Folder::hasCutFiles() const {
+    return cutFilesHashSet_
+            && !cutFilesHashSet_->empty()
+            && cutFilesDirPath_ == QString::fromUtf8(dirPath_.toString().get());
+}
+
 // checks whether there were cut files here
-// and if there were, invalidates this last cut path
-bool Folder::hadCutFilesUnset() {
-    if(lastCutFilesDirPath_ == dirPath_.toString().get()) {
+// and if so, invalidates the last cut path
+bool Folder::hadCutFiles() {
+    if(lastCutFilesDirPath_ == QString::fromUtf8(dirPath_.toString().get())) {
         lastCutFilesDirPath_ = QString();
         return true;
     }
     return false;
 }
 
-bool Folder::hasCutFiles() {
-    return cutFilesHashSet_
-            && !cutFilesHashSet_->empty()
-            && cutFilesDirPath_ == dirPath_.toString().get();
-}
-
-void Folder::setCutFiles(const std::shared_ptr<const HashSet>& cutFilesHashSet) {
-    if(cutFilesHashSet_ && !cutFilesHashSet_->empty()) {
-        lastCutFilesDirPath_ = cutFilesDirPath_;
+// can be called to emit a signal whenever the list of cut files changes
+void Folder::updateCutFiles() {
+    auto tmp = files();
+    std::vector<FileInfoPair> cut_files_to_update;
+    for(auto& file : tmp) {
+        auto fileInfoPtr = std::make_shared<FileInfo>(file->gFileInfo(), file->path());
+        if(cutFilesHashSet_
+           && cutFilesHashSet_->count(file->path().hash())) {
+            fileInfoPtr->bindCutFiles(cutFilesHashSet_);
+        }
+        auto it = files_.find(file->path().baseName().get());
+        if(it != files_.end()) {
+            cut_files_to_update.push_back(std::make_pair(it->second, fileInfoPtr));
+        }
+        files_[fileInfoPtr->path().baseName().get()] = fileInfoPtr;
+    }
+    if(!cut_files_to_update.empty()) {
+        Q_EMIT cutFilesChanged(cut_files_to_update);
     }
-    cutFilesDirPath_ = dirPath_.toString().get();
-    cutFilesHashSet_ = cutFilesHashSet;
 }
 
 void Folder::onDirListFinished() {
