@@ -29,7 +29,7 @@
 #include <QStandardPaths>
 #include <QFileDialog>
 #include <sys/types.h>
-#include <time.h>
+#include <ctime>
 #include "core/totalsizejob.h"
 #include "core/folder.h"
 
@@ -157,7 +157,7 @@ void FilePropsDialog::initPermissionsPage() {
     // Let's make it clear for the users
     // init combo boxes for file permissions here
     QStringList comboItems;
-    comboItems.append("---"); // no change
+    comboItems.append(QStringLiteral("---")); // no change
     if(singleType && hasDir) { // all files are dirs
         comboItems.append(tr("View folder content"));
         comboItems.append(tr("View and modify folder content"));
@@ -265,8 +265,8 @@ void FilePropsDialog::initGeneralPage() {
             if(!icon) { // get an icon from mime type if needed
                 icon = mimeType->icon();
             }
-            ui->fileType->setText(mimeType->desc());
-            ui->mimeType->setText(mimeType->name());
+            ui->fileType->setText(QString::fromUtf8(mimeType->desc()));
+            ui->mimeType->setText(QString::fromUtf8(mimeType->name()));
         }
         if(icon) {
             ui->iconButton->setIcon(icon->qicon());
@@ -294,9 +294,9 @@ void FilePropsDialog::initGeneralPage() {
         auto parent_path = fileInfo->path().parent();
         auto parent_str = parent_path ? parent_path.displayName(): nullptr;
 
-        ui->fileName->setText(fileInfo->displayName());
+        ui->fileName->setText(QString::fromStdString(fileInfo->name()));
         if(parent_str) {
-            ui->location->setText(parent_str.get());
+            ui->location->setText(QString::fromUtf8(parent_str.get()));
         }
         else {
             ui->location->clear();
@@ -335,8 +335,8 @@ void FilePropsDialog::initGeneralPage() {
             ui->progressBar->setValue(qRound(static_cast<qreal>((total - free) * 100) / static_cast<qreal>(total)));
             ui->progressBar->setFormat(tr("%p% used"));
             ui->spaceLabel->setText(tr("%1 Free of %2")
-                                    .arg(formatFileSize(free, false))
-                                    .arg(formatFileSize(total, false)));
+                                    .arg(formatFileSize(free, false),
+                                         formatFileSize(total, false)));
         }
     }
     if(!canShowDeviceUsage) {
@@ -367,12 +367,12 @@ void FilePropsDialog::onFileSizeTimerTimeout() {
         // they use unsigned long instead of int.
         // We cannot use Qt here to handle plural forms. So sad. :-(
         QString str = Fm::formatFileSize(totalSizeJob->totalSize(), fm_config->si_unit) %
-                      QString(" (%1 B)").arg(totalSizeJob->totalSize());
+                      QStringLiteral(" (%1 B)").arg(totalSizeJob->totalSize());
         // tr(" (%n) byte(s)", "", deepCountJob->total_size);
         ui->fileSize->setText(str);
 
         str = Fm::formatFileSize(totalSizeJob->totalOnDiskSize(), fm_config->si_unit) %
-              QString(" (%1 B)").arg(totalSizeJob->totalOnDiskSize());
+              QStringLiteral(" (%1 B)").arg(totalSizeJob->totalOnDiskSize());
         // tr(" (%n) byte(s)", "", deepCountJob->total_ondisk_size);
         ui->onDiskSize->setText(str);
 
@@ -393,10 +393,10 @@ void FilePropsDialog::onIconButtonclicked() {
     QString iconDir;
     QString iconThemeName = QIcon::themeName();
     QStringList icons = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation,
-                                                  "icons",
+                                                  QStringLiteral("icons"),
                                                   QStandardPaths::LocateDirectory);
     for (QStringList::ConstIterator it = icons.constBegin(); it != icons.constEnd(); ++it) {
-        QString iconThemeFolder = *it + '/' + iconThemeName;
+        QString iconThemeFolder = *it + QLatin1String("/") + iconThemeName;
         if (QDir(iconThemeFolder).exists() && QFileInfo(iconThemeFolder).permission(QFileDevice::ReadUser)) {
             // give priority to the "places" folder
             const QString places = iconThemeFolder + QLatin1String("/places");
@@ -411,7 +411,7 @@ void FilePropsDialog::onIconButtonclicked() {
     }
     if(iconDir.isEmpty()) {
         iconDir = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                         "icons",
+                                         QStringLiteral("icons"),
                                          QStandardPaths::LocateDirectory);
         if(iconDir.isEmpty()) {
             return;
@@ -421,10 +421,10 @@ void FilePropsDialog::onIconButtonclicked() {
                                                           iconDir,
                                                           tr("Images (*.png *.xpm *.svg *.svgz )"));
     if(!iconPath.isEmpty()) {
-        QStringList parts = iconPath.split("/", QString::SkipEmptyParts);
+        QStringList parts = iconPath.split(QStringLiteral("/"), QString::SkipEmptyParts);
         if(!parts.isEmpty()) {
             QString iconName = parts.at(parts.count() - 1);
-            int ln = iconName.lastIndexOf(".");
+            int ln = iconName.lastIndexOf(QLatin1String("."));
             if(ln > -1) {
                 iconName.remove(ln, iconName.length() - ln);
                 customIcon = QIcon::fromTheme(iconName);
@@ -530,7 +530,7 @@ void FilePropsDialog::accept() {
     // Renaming
     if(singleFile) {
         QString new_name = ui->fileName->text();
-        if(fileInfo->displayName() != new_name) {
+        if(QString::fromStdString(fileInfo->name()) != new_name) {
             auto path = fileInfo->path();
             auto parent_path = path.parent();
             auto dest = parent_path.child(new_name.toLocal8Bit().constData());
