@@ -29,6 +29,10 @@
 #include <QPixmap>
 #include <QPainter>
 #include <QTimer>
+#include <QDateTime>
+#include <QString>
+#include <QApplication>
+#include <QClipboard>
 #include "utilities.h"
 #include "fileoperation.h"
 
@@ -38,6 +42,7 @@ FolderModel::FolderModel():
     hasPendingThumbnailHandler_{false},
     showFullNames_{false},
     isLoaded_{false} {
+    connect(QApplication::clipboard(), &QClipboard::dataChanged, this, &FolderModel::onClipboardDataChange);
 }
 
 FolderModel::~FolderModel() {
@@ -57,6 +62,7 @@ void FolderModel::setFolder(const std::shared_ptr<Fm::Folder>& new_folder) {
         connect(folder_.get(), &Fm::Folder::finishLoading, this, &FolderModel::onFinishLoading);
         connect(folder_.get(), &Fm::Folder::filesAdded, this, &FolderModel::onFilesAdded);
         connect(folder_.get(), &Fm::Folder::filesChanged, this, &FolderModel::onFilesChanged);
+        connect(folder_.get(), &Fm::Folder::cutFilesChanged, this, &FolderModel::onCutFilesChanged);
         connect(folder_.get(), &Fm::Folder::filesRemoved, this, &FolderModel::onFilesRemoved);
         // handle the case if the folder is already loaded
         if(folder_->isLoaded()) {
@@ -74,6 +80,10 @@ void FolderModel::onStartLoading() {
 
 void FolderModel::onFinishLoading() {
     isLoaded_ = true;
+    // files may have been cut by another app
+    if(!folder_->hasCutFiles()) {
+        onClipboardDataChange();
+    }
 }
 
 void FolderModel::onFilesAdded(const Fm::FileInfoList& files) {
@@ -116,6 +126,20 @@ void FolderModel::onFilesChanged(std::vector<Fm::FileInfoPair>& files) {
     }
 }
 
+void FolderModel::onCutFilesChanged(std::vector<Fm::FileInfoPair>& files) {
+    for(auto& change : files) {
+        int row;
+        auto& oldInfo = change.first;
+        auto& newInfo = change.second;
+        QList<FolderModelItem>::iterator it = findItemByFileInfo(oldInfo.get(), &row);
+        if(it != items.end()) {
+            FolderModelItem& item = *it;
+            item.info = newInfo;
+        }
+    }
+    Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, 0)); // update all items
+}
+
 void FolderModel::onFilesRemoved(const Fm::FileInfoList& files) {
     for(auto& info : files) {
         int row;
@@ -163,19 +187,47 @@ void FolderModel::insertFiles(int row, const Fm::FileInfoList& files) {
     endInsertRows();
 }
 
-void FolderModel::setCutFiles(const QItemSelection& selection) {
+void FolderModel::onClipboardDataChange() {
     if(folder_) {
-        if(!selection.isEmpty()) {
-            auto cutFilesHashSet = std::make_shared<HashSet>();
-            folder_->setCutFiles(cutFilesHashSet);
-            const auto indexes = selection.indexes();
-            for(const auto& index : indexes) {
-                auto item = itemFromIndex(index);
-                item->bindCutFiles(cutFilesHashSet);
-                cutFilesHashSet->insert(item->info->path().hash());
+        const QClipboard* clipboard = QApplication::clipboard();
+        const QMimeData* data = clipboard->mimeData();
+        Fm::FilePathList paths;
+        bool isCutSelection;
+        std::tie(paths, isCutSelection) = Fm::parseClipboardData(*data);
+        if(isCutSelection) { // a file is cut
+            auto cutDirPath = paths.size() > 0 ? paths[0].parent() : FilePath();
+            if(folder_->path() == cutDirPath) { // the cut file is in this folder
+                setCutFiles(paths);
             }
+            else if(folder_->hadCutFiles() || folder_->hasCutFiles()) {
+                if(Folder::findByPath(cutDirPath) == nullptr) {
+                    // the cut file is in a folder that is not loaded (i.e., it is cut by another app)
+                    folder_->setCutFiles(std::make_shared<HashSet>());
+                }
+                folder_->updateCutFiles();
+            }
+            return;
         }
-        Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, 0));
+        // no file is cut
+        folder_->setCutFiles(std::make_shared<HashSet>()); // clean Folder::cutFilesHashSet_
+        if(folder_->hadCutFiles()) {
+            folder_->updateCutFiles();
+        }
+    }
+}
+
+void FolderModel::setCutFiles(const Fm::FilePathList& paths) {
+    if(folder_ && !paths.empty()) {
+        auto cutFilesHashSet = std::make_shared<HashSet>();
+        folder_->setCutFiles(cutFilesHashSet);
+
+        auto path_it = paths.begin();
+        while(path_it != paths.end()) {
+            const auto& path = *path_it;
+            cutFilesHashSet->insert(path.hash());
+            ++path_it;
+        }
+        folder_->updateCutFiles();
     }
 }
 
@@ -211,6 +263,36 @@ std::shared_ptr<const Fm::FileInfo> FolderModel::fileInfoFromIndex(const QModelI
     return item ? item->info : nullptr;
 }
 
+QString FolderModel::makeTooltip(FolderModelItem* item) const {
+    // name (bold)
+    QString tip = QStringLiteral("<p><b>") + (showFullNames_ ? QString::fromStdString(item->name()) : item->displayName()).toHtmlEscaped() + QStringLiteral("</b></p>");
+    // parent dir
+    auto info = item->info;
+    auto parent_path = info->path().parent();
+    auto parent_str = parent_path ? parent_path.displayName() : nullptr;
+    if(parent_str) {
+        tip += QStringLiteral("<p><i>") + tr("Location:") + QStringLiteral("</i> ") + QString::fromUtf8(parent_str.get()).toHtmlEscaped() + QStringLiteral("</p>");
+    }
+    // file type
+    tip += QStringLiteral("<i>") + tr("File type:") + QStringLiteral("</i> ") + QString::fromUtf8(info->mimeType()->desc());
+    // file size
+    const QString dSize = item->displaySize();
+    if(!dSize.isEmpty()) { // it's empty for directories
+        tip += QStringLiteral("<br><i>") + tr("File size:") + QStringLiteral("</i> ") + dSize;
+    }
+    // times
+    auto atime = QDateTime::fromMSecsSinceEpoch(info->atime() * 1000);
+    tip += QStringLiteral("<br><i>") + tr("Last modified:") + QStringLiteral("</i> ") + item->displayMtime()
+           + QStringLiteral("<br><i>") + tr("Last accessed:") + QStringLiteral("</i> ") + atime.toString(Qt::SystemLocaleShortDate);
+    // owner
+    const QString owner = item->ownerName();
+    if(!owner.isEmpty()) { // can be empty
+        tip += QStringLiteral("<br><i>") + tr("Owner:") + QStringLiteral("</i> ") + owner
+               + QStringLiteral("<br><i>") + tr("Group:") + QStringLiteral("</i> ") + item->ownerGroup();
+    }
+    return tip;
+}
+
 QVariant FolderModel::data(const QModelIndex& index, int role/* = Qt::DisplayRole*/) const {
     if(!index.isValid() || index.row() > items.size() || index.column() >= NumOfColumns) {
         return QVariant();
@@ -225,16 +307,18 @@ QVariant FolderModel::data(const QModelIndex& index, int role/* = Qt::DisplayRol
 
     switch(role) {
     case Qt::ToolTipRole:
-        return QVariant(item->displayName());
+        return QVariant(makeTooltip(item));
     case Qt::DisplayRole:  {
         switch(index.column()) {
         case ColumnFileName:
             return (showFullNames_ && !item->name().empty() ? QString::fromStdString(item->name())
                                                             : item->displayName());
         case ColumnFileType:
-            return QString(info->mimeType()->desc());
+            return QString::fromUtf8(info->mimeType()->desc());
         case ColumnFileMTime:
             return item->displayMtime();
+        case ColumnFileDTime:
+            return item->displayDtime();
         case ColumnFileSize:
             return item->displaySize();
         case ColumnFileOwner:
@@ -283,6 +367,9 @@ QVariant FolderModel::headerData(int section, Qt::Orientation orientation, int r
             case ColumnFileMTime:
                 title = tr("Modified");
                 break;
+            case ColumnFileDTime:
+                title = tr("Deleted");
+                break;
             case ColumnFileOwner:
                 title = tr("Owner");
                 break;
@@ -324,22 +411,16 @@ Qt::ItemFlags FolderModel::flags(const QModelIndex& index) const {
     return flags;
 }
 
-// FIXME: this is very inefficient and should be replaced with a
-// more reasonable implementation later.
-QList<FolderModelItem>::iterator FolderModel::findItemByPath(const Fm::FilePath& path, int* row) {
-    QList<FolderModelItem>::iterator it = items.begin();
-    int i = 0;
+std::shared_ptr<const Fm::FileInfo> FolderModel::fileInfoFromPath(const Fm::FilePath& path) const {
+    QList<FolderModelItem>::const_iterator it = items.begin();
     while(it != items.end()) {
-        FolderModelItem& item = *it;
-        auto item_path = item.info->path();
-        if(item_path == path) {
-            *row = i;
-            return it;
+        const FolderModelItem& item = *it;
+        if(item.info->path() == path) {
+            return item.info;
         }
         ++it;
-        ++i;
     }
-    return items.end();
+    return nullptr;
 }
 
 // FIXME: this is very inefficient and should be replaced with a
@@ -382,31 +463,48 @@ QStringList FolderModel::mimeTypes() const {
     // add support for freedesktop Xdnd direct save (XDS) protocol.
     // https://www.freedesktop.org/wiki/Specifications/XDS/#index4h2
     // the real implementation is in FolderView::childDropEvent().
-    types << "XdndDirectSave0";
-    types << "text/uri-list";
-    // types << "x-special/gnome-copied-files";
+    types << QStringLiteral("XdndDirectSave0");
+    types << QStringLiteral("text/uri-list");
+    types << QStringLiteral("libfm/files"); // see FolderModel::mimeData() below
     return types;
 }
 
 QMimeData* FolderModel::mimeData(const QModelIndexList& indexes) const {
     QMimeData* data = QAbstractItemModel::mimeData(indexes);
     //qDebug("FolderModel::mimeData");
-    // build a uri list
-    QByteArray urilist;
+    // build two uri lists, one for internal DND
+    // and the other for DNDing to external apps
+    QByteArray urilist, libfmUrilist;
     urilist.reserve(4096);
+    libfmUrilist.reserve(4096);
 
     for(const auto& index : indexes) {
         FolderModelItem* item = itemFromIndex(index);
         if(item && item->info) {
             auto path = item->info->path();
             if(path.isValid()) {
+                // get the list that will be used by internal DND
                 auto uri = path.uri();
-                urilist.append(uri.get());
+                libfmUrilist.append(uri.get());
+                libfmUrilist.append('\n');
+
+                // also, get the list that will be used when DNDing to external apps,
+                // using local paths as far as possible (for DNDing from remote folders)
+                if(auto localPath = path.localPath()) {
+                    QUrl url = QUrl::fromLocalFile(QString::fromUtf8(localPath.get()));
+                    urilist.append(url.toEncoded());
+                }
+                else {
+                    urilist.append(uri.get());
+                }
                 urilist.append('\n');
             }
         }
     }
-    data->setData("text/uri-list", urilist);
+    data->setData(QStringLiteral("text/uri-list"), urilist);
+    // NOTE: The mimetype "text/uri-list" changes the list in QMimeData::setData() to get URLs
+    // but some protocols (like MTP) may need the original list to query file info.
+    data->setData(QStringLiteral("libfm/files"), libfmUrilist);
 
     return data;
 }
@@ -423,7 +521,7 @@ bool FolderModel::dropMimeData(const QMimeData* data, Qt::DropAction action, int
             info = fileInfoFromIndex(parent);
         }
         else {
-            QModelIndex itemIndex = parent.child(row, column);
+            QModelIndex itemIndex = index(row, column, parent);
             info = fileInfoFromIndex(itemIndex);
         }
         if(info) {
@@ -442,10 +540,19 @@ bool FolderModel::dropMimeData(const QMimeData* data, Qt::DropAction action, int
         destPath = path();
     }
 
+    Fm::FilePathList srcPaths;
+    // try to get paths from the original data
+    if(data->hasFormat(QStringLiteral("libfm/files"))) {
+        QByteArray _data = data->data(QStringLiteral("libfm/files"));
+        srcPaths = pathListFromUriList(_data.data());
+    }
+    if(srcPaths.empty() && data->hasUrls()) {
+        srcPaths = Fm::pathListFromQUrls(data->urls());
+    }
+
     // FIXME: should we put this in dropEvent handler of FolderView instead?
-    if(data->hasUrls()) {
+    if(!srcPaths.empty()) {
         //qDebug("drop action: %d", action);
-        auto srcPaths = pathListFromQUrls(data->urls());
         switch(action) {
         case Qt::CopyAction:
             FileOperation::copyFiles(srcPaths, destPath);
@@ -461,7 +568,7 @@ bool FolderModel::dropMimeData(const QMimeData* data, Qt::DropAction action, int
         }
         return true;
     }
-    else if(data->hasFormat("application/x-qabstractitemmodeldatalist")) {
+    else if(data->hasFormat(QStringLiteral("application/x-qabstractitemmodeldatalist"))) {
         return true;
     }
     return QAbstractListModel::dropMimeData(data, action, row, column, parent);
