@@ -51,6 +51,8 @@
 #include "folderview_p.h"
 #include "utilities.h"
 
+#include <algorithm>
+
 #define SCROLL_FRAMES_PER_SEC 50
 #define SCROLL_DURATION 300 // in ms
 
@@ -61,11 +63,18 @@ using namespace Fm;
 FolderViewListView::FolderViewListView(QWidget* parent):
     QListView(parent),
     activationAllowed_(true),
-    cursorOnSelectionCorner_(false) {
+    cursorOnSelectionCorner_(false),
+    mouseLeftPressed_(false) {
     connect(this, &QListView::activated, this, &FolderViewListView::activation);
     // inline renaming
     setEditTriggers(QAbstractItemView::NoEditTriggers);
     setMouseTracking(true); // needed with selection corner icon
+
+    viewport()->setAcceptDrops(true);
+    /* If the list view is already visible, setMovement() will lay out items again with delay
+       (see Qt, QListView::setMovement(), d->doDelayedItemsLayout()) and thus drop events will
+       remain disabled for its viewport. So, we should call it here, before showing the view. */
+    setMovement(QListView::Static);
 }
 
 FolderViewListView::~FolderViewListView() {
@@ -81,17 +90,41 @@ void FolderViewListView::startDrag(Qt::DropActions supportedActions) {
 }
 
 void FolderViewListView::mousePressEvent(QMouseEvent* event) {
-    setSelectionMode(cursorOnSelectionCorner_ && event->button() == Qt::LeftButton
-                         ? QAbstractItemView::MultiSelection
-                         : QAbstractItemView::ExtendedSelection);
+    if(event->buttons() == Qt::LeftButton) { // see FolderViewListView::mouseMoveEvent
+        mouseLeftPressed_ = true;
+        if(indexAt(event->pos()).isValid()) {
+            globalItemPressPoint_ = event->globalPos();
+        }
+        else {
+            globalItemPressPoint_ = QPoint();
+        }
+    }
+    // use the selection corner only with the extended and multiple selection modes
+    // and change the mode to multiple temporarily if it is extended
+    QAbstractItemView::SelectionMode sm = selectionMode();
+    if(sm == QAbstractItemView::ExtendedSelection
+       && cursorOnSelectionCorner_ && event->button() == Qt::LeftButton) {
+        setSelectionMode(QAbstractItemView::MultiSelection);
+    }
     QListView::mousePressEvent(event);
+    if (sm == QAbstractItemView::ExtendedSelection) {
+        setSelectionMode(sm); // restore the selection mode
+    }
     static_cast<FolderView*>(parent())->childMousePressEvent(event);
 }
 
 void FolderViewListView::mouseMoveEvent(QMouseEvent* event) {
-    // NOTE: Filter the BACK & FORWARD buttons to not Drag & Drop with them.
-    // (by default Qt views drag with any button)
-    if (event->buttons() == Qt::NoButton || (event->buttons() & ~(Qt::BackButton | Qt::ForwardButton))) {
+    if (event->buttons() == Qt::NoButton
+        // NOTE: Filter the BACK & FORWARD buttons to not Drag & Drop with them.
+        // (by default Qt views drag with any button)
+        || ((event->buttons() & ~(Qt::BackButton | Qt::ForwardButton))
+            && !(event->buttons() == Qt::LeftButton
+                    // don't draw rubberband if left mouse button isn't pressed inside view
+                    // (this event may have been sent by FolderView::scrollSmoothly)
+                && (!mouseLeftPressed_
+                    // don't start drag if the cursor isn't moved since pressing left mouse button on an item
+                    // (because the user may want to scroll the view with mouse wheel before dragging)
+                    || globalItemPressPoint_ == event->globalPos())))) {
         bool cursorOnSelectionCorner = cursorOnSelectionCorner_;
         QListView::mouseMoveEvent(event);
         // update the index if the cursor enters/leaves the selection corner icon
@@ -125,12 +158,14 @@ QModelIndex FolderViewListView::indexAt(const QPoint& point) const {
         // the selection (hover) corner is a rectangle near the top left corner of
         // the icon and outside it as far as possible, so that its width and height
         // are 1/3 of the icon size >= 48 px (see FolderItemDelegate::paint)
-        if(isCursorPos && _iconSize.width() >= 48) {
+        if(isCursorPos && _iconSize.width() >= 48
+           && (selectionMode() == QAbstractItemView::ExtendedSelection
+               || selectionMode() == QAbstractItemView::MultiSelection)) {
             int s = _iconSize.width() / 3;
-            iconLeft = qMax(visRect.left(), iconLeft - s);
-            iconTop = qMax(visRect.top(), iconTop - s);
-            if(point.x() >= iconLeft &&  point.x() <= iconLeft + s
-               && point.y() >= iconTop &&  point.y() <= iconTop + s) {
+            int icnLeft = qMax(visRect.left(), iconLeft - s);
+            int icnTop = qMax(visRect.top(), iconTop - s);
+            if(point.x() >= icnLeft &&  point.x() <= icnLeft + s
+               && point.y() >= icnTop &&  point.y() <= icnTop + s) {
                 cursorOnSelectionCorner_ = true;
                 return index;
             }
@@ -216,6 +251,9 @@ void FolderViewListView::dropEvent(QDropEvent* e) {
 }
 
 void FolderViewListView::mouseReleaseEvent(QMouseEvent* event) {
+    // NOTE: With mouseReleaseEvent, event->buttons() excludes the button that caused the event
+    // and so, it should not be used here. Instead, event->button() is used.
+
     bool activationWasAllowed = activationAllowed_;
     if(!style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, nullptr, this)
        || event->button() != Qt::LeftButton
@@ -227,6 +265,9 @@ void FolderViewListView::mouseReleaseEvent(QMouseEvent* event) {
     QListView::mouseReleaseEvent(event);
 
     activationAllowed_ = activationWasAllowed;
+    if(event->button() == Qt::LeftButton) {
+        mouseLeftPressed_ = false;
+    }
 }
 
 void FolderViewListView::mouseDoubleClickEvent(QMouseEvent* event) {
@@ -269,6 +310,19 @@ void FolderViewListView::activation(const QModelIndex& index) {
     }
 }
 
+void FolderViewListView::selectAll() {
+    // NOTE: By default QListView::selectAll() selects all columns in the model.
+    // However, QListView only show the first column. Normal selection by mouse
+    // can only select the first column of every row. I consider this discripancy yet
+    // another design flaw of Qt. To make them consistent, we do it ourselves by only
+    // selecting the first column of every row and do not select all columns as Qt does.
+    // I'll report a Qt bug for this later.
+    if(QAbstractItemModel* model_ = model()) {
+        const QItemSelection sel{model_->index(0, 0), model_->index(model_->rowCount() - 1, 0)};
+        selectionModel()->select(sel, QItemSelectionModel::Select);
+    }
+}
+
 //-----------------------------------------------------------------------------
 
 FolderViewTreeView::FolderViewTreeView(QWidget* parent):
@@ -355,14 +409,27 @@ void FolderViewTreeView::headerContextMenu(const QPoint &p) {
     if(model()) {
         menu.addSeparator();
         QWidgetAction *labelAction = new QWidgetAction(&menu);
-        QLabel *label = new QLabel("<center><b>" + tr("Visible Columns") + "</b></center>");
+        QLabel *label = new QLabel(QStringLiteral("<center><b>") + tr("Visible Columns") + QStringLiteral("</b></center>"));
         labelAction->setDefaultWidget(label);
         menu.addAction (labelAction);
 
         int filenameColumn = header()->visualIndex(FolderModel::ColumnFileName);
+        int dTimeColumn = header()->visualIndex(FolderModel::ColumnFileDTime);
+        bool isTrash = false;
+        if(ProxyFolderModel* proxyModel = qobject_cast<ProxyFolderModel*>(model())) {
+            if(auto model = static_cast<FolderModel*>(proxyModel->sourceModel())) {
+                if(model->path() && strcmp(model->path().toString().get(), "trash:///") == 0) {
+                    isTrash = true;
+                }
+            }
+        }
         int numCols = header()->count();
         for(int column = 0; column < numCols; ++column) {
             int columnId = header()->logicalIndex(column);
+            if(!isTrash && columnId == dTimeColumn) {
+                // no action for the deletion time column if this isn't trash
+                continue;
+            }
             if(columnId >= 0 && columnId < FolderModel::NumOfColumns) {
                 action = menu.addAction (model()->headerData(columnId, Qt::Horizontal, Qt::DisplayRole).toString());
                 action->setCheckable(true);
@@ -372,7 +439,7 @@ void FolderViewTreeView::headerContextMenu(const QPoint &p) {
                 }
                 else {
                     action->setChecked(!header()->isSectionHidden(columnId));
-                    connect(action, &QAction::triggered, action, [this, column, columnId] (bool checked) {
+                    connect(action, &QAction::triggered, action, [this, column] (bool checked) {
                         if(checked) {
                             hiddenColumns_.remove(column);
                         }
@@ -417,24 +484,29 @@ void FolderViewTreeView::paintEvent(QPaintEvent * event) {
 }
 
 void FolderViewTreeView::mousePressEvent(QMouseEvent* event) {
-    QAbstractItemView::mousePressEvent(event);
-
-    // remember mouse press position and determine whether selections should be kept
-    // or removed later, when the cursor moves
-    mousePressPoint_ = event->pos() + QPoint(horizontalOffset(), verticalOffset());
-    QModelIndex index = indexAt(event->pos());
-    if(index.isValid()) {
-        QItemSelectionModel::SelectionFlags command;
-        Qt::KeyboardModifiers modifiers = QApplication::keyboardModifiers();
-        const Qt::MouseButton button = static_cast<const QMouseEvent*>(event)->button();
-        const bool shiftKeyPressed = modifiers & Qt::ShiftModifier;
-        const bool controlKeyPressed = modifiers & Qt::ControlModifier;
-        const bool rightButtonPressed = button & Qt::RightButton;
-        const bool indexIsSelected = selectionModel()->isSelected(index);
-        if(controlKeyPressed && !shiftKeyPressed && !rightButtonPressed) {
-            ctrlDragSelectionFlag_ = indexIsSelected ? QItemSelectionModel::Deselect : QItemSelectionModel::Select;
+    if(event->buttons() == Qt::LeftButton) { // see FolderViewTreeView::mouseMoveEvent
+        globalItemPressPoint_ = event->globalPos();
+    }
+    if(selectionMode() == QAbstractItemView::ExtendedSelection) {
+        // remember mouse press position and determine whether selections should be kept
+        // or removed later, when the cursor moves
+        QAbstractItemView::mousePressEvent(event);
+        mousePressPoint_ = event->pos() + QPoint(horizontalOffset(), verticalOffset());
+        QModelIndex index = indexAt(event->pos());
+        if(index.isValid()) {
+            Qt::KeyboardModifiers modifiers = QApplication::keyboardModifiers();
+            const bool shiftKeyPressed = modifiers & Qt::ShiftModifier;
+            const bool controlKeyPressed = modifiers & Qt::ControlModifier;
+            const bool rightButtonPressed = event->button() & Qt::RightButton;
+            const bool indexIsSelected = selectionModel()->isSelected(index);
+            if(controlKeyPressed && !shiftKeyPressed && !rightButtonPressed) {
+                ctrlDragSelectionFlag_ = indexIsSelected ? QItemSelectionModel::Deselect : QItemSelectionModel::Select;
+            }
         }
     }
+    else {
+        QTreeView::mousePressEvent(event);
+    }
 
     static_cast<FolderView*>(parent())->childMousePressEvent(event);
 }
@@ -444,7 +516,8 @@ void FolderViewTreeView::mouseMoveEvent(QMouseEvent* event) {
     // (by default Qt views drag with any button)
     if(event->buttons() == Qt::NoButton || (event->buttons() & ~(Qt::BackButton | Qt::ForwardButton))) {
         // handle rubberband
-        if((event->buttons() & Qt::LeftButton)
+        if(selectionMode() == QAbstractItemView::ExtendedSelection
+            && (event->buttons() & Qt::LeftButton)
             && (rubberBandRect_.isValid()
                 || !indexAt(mousePressPoint_ - QPoint(horizontalOffset(), verticalOffset())).isValid())) {
             QAbstractItemView::mouseMoveEvent(event);
@@ -479,13 +552,18 @@ void FolderViewTreeView::mouseMoveEvent(QMouseEvent* event) {
             setSelection(selectionRect, command);
         }
         else {
-            QTreeView::mouseMoveEvent(event);
+            // don't start drag if the cursor isn't moved since pressing left mouse button on an item
+            // because the user may want to scroll the view with mouse wheel before dragging
+            if(!(event->buttons() == Qt::LeftButton && globalItemPressPoint_ == event->globalPos())) {
+                QTreeView::mouseMoveEvent(event);
+            }
         }
     }
 }
 
 void FolderViewTreeView::setSelection(const QRect &rect, QItemSelectionModel::SelectionFlags command) {
-    if(model() && state() == QAbstractItemView::DragSelectingState) { // rubberband selection
+    if(selectionMode() == QAbstractItemView::ExtendedSelection
+       && model() && state() == QAbstractItemView::DragSelectingState) { // rubberband selection
         QRect r = rubberBandRect_.adjusted(-horizontalOffset(), -verticalOffset(),
                                             -horizontalOffset(), -verticalOffset());
         r.setLeft(qMax(0, r.left()));
@@ -556,10 +634,26 @@ void FolderViewTreeView::layoutColumns() {
             opt.sortIndicator = QStyleOptionHeader::SortDown;
         }
         QAbstractItemModel* model_ = model();
+        int filenameColumn = headerView->visualIndex(FolderModel::ColumnFileName);
+        int dTimeColumn = header()->visualIndex(FolderModel::ColumnFileDTime);
+        bool isTrash = false;
+        if(ProxyFolderModel* proxyModel = qobject_cast<ProxyFolderModel*>(model())) {
+            if(auto model = static_cast<FolderModel*>(proxyModel->sourceModel())) {
+                if(model->path() && strcmp(model->path().toString().get(), "trash:///") == 0) {
+                    isTrash = true;
+                }
+            }
+        }
         int column;
         for(column = 0; column < numCols; ++column) {
             int columnId = headerView->logicalIndex(column);
 
+            if(!isTrash && columnId == dTimeColumn) {
+                // hide the deletion time column if this isn't trash
+                headerView->setSectionHidden(columnId, true);
+                continue;
+            }
+
             // handle hidden columns
             bool wasHidden = false;
             if(headerView->isSectionHidden(columnId)) {
@@ -571,7 +665,8 @@ void FolderViewTreeView::layoutColumns() {
                     continue;
                 }
             }
-            else if(hiddenColumns_.contains(columnId)) {
+            else if(hiddenColumns_.contains(columnId)
+                    && columnId != filenameColumn) { // never hide the name column
                 headerView->setSectionHidden(columnId, true);
                 continue;
             }
@@ -610,7 +705,6 @@ void FolderViewTreeView::layoutColumns() {
             desiredWidth += widths[column];
         }
 
-        int filenameColumn = headerView->visualIndex(FolderModel::ColumnFileName);
         if(customColumnWidths_.size() <= filenameColumn) { // practically means no custom width
             // if the total witdh we want exceeds the available space
             if(desiredWidth > availWidth) {
@@ -709,11 +803,16 @@ void FolderViewTreeView::mouseReleaseEvent(QMouseEvent* event) {
         activationAllowed_ = false;
     }
 
-    QAbstractItemView::mouseReleaseEvent(event);
-    viewport()->update(rubberBandRect_.adjusted(-horizontalOffset(), -verticalOffset(),
-                                                -horizontalOffset(), -verticalOffset()));
-    rubberBandRect_ = QRect();
-    ctrlDragSelectionFlag_ = QItemSelectionModel::NoUpdate;
+    if(selectionMode() == QAbstractItemView::ExtendedSelection) {
+        QAbstractItemView::mouseReleaseEvent(event);
+        viewport()->update(rubberBandRect_.adjusted(-horizontalOffset(), -verticalOffset(),
+                                                    -horizontalOffset(), -verticalOffset()));
+        rubberBandRect_ = QRect();
+        ctrlDragSelectionFlag_ = QItemSelectionModel::NoUpdate;
+    }
+    else {
+        QTreeView::mouseReleaseEvent(event);
+    }
 
     activationAllowed_ = activationWasAllowed;
 
@@ -760,8 +859,8 @@ FolderView::FolderView(FolderView::ViewMode _mode, QWidget *parent):
     selChangedTimer_(nullptr),
     itemDelegateMargins_(QSize(3, 3)),
     shadowHidden_(false),
-    smoothScrollTimer_(nullptr),
-    wheelEvent_(nullptr) {
+    ctrlRightClick_(false),
+    smoothScrollTimer_(nullptr) {
 
     iconSize_[IconMode - FirstViewMode] = QSize(48, 48);
     iconSize_[CompactMode - FirstViewMode] = QSize(24, 24);
@@ -776,7 +875,6 @@ FolderView::FolderView(FolderView::ViewMode _mode, QWidget *parent):
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
     connect(this, &FolderView::clicked, this, &FolderView::onFileClicked);
-    connect(QApplication::clipboard(), &QClipboard::dataChanged, this, &FolderView::onClipboardDataChange);
 }
 
 FolderView::~FolderView() {
@@ -816,13 +914,28 @@ void FolderView::setHiddenColumns(const QList<int> &columns) {
 }
 
 void FolderView::onItemActivated(QModelIndex index) {
-    QItemSelectionModel* selModel = selectionModel();
-    if(index.isValid() && index.model()
-       && selModel && selModel->isSelected(index)) { // do nothing when the item is not selected
-        QVariant data = index.model()->data(index, FolderModel::FileInfoRole);
-        auto info = data.value<std::shared_ptr<const Fm::FileInfo>>();
-        if(info) {
-            if(!(QApplication::keyboardModifiers() & (Qt::ShiftModifier | Qt::ControlModifier | Qt::AltModifier | Qt::MetaModifier))) {
+    if(QApplication::keyboardModifiers() & (Qt::ShiftModifier | Qt::ControlModifier | Qt::AltModifier | Qt::MetaModifier)) {
+        return;
+    }
+    if(QItemSelectionModel* selModel = selectionModel()) {
+        QVariant data;
+        if(index.isValid() && selModel->isSelected(index)) { // activate index only if it is selected
+            if(index.model()) {
+                data = index.model()->data(index, FolderModel::FileInfoRole);
+            }
+        }
+        else { // if index is not valid or selected, activate the first selected index
+            QModelIndexList selIndexes = mode == DetailedListMode ? selectedRows() : selectedIndexes();
+            if(!selIndexes.isEmpty()) {
+                QModelIndex first = selIndexes.first();
+                if(first.model()) {
+                    data = first.model()->data(first, FolderModel::FileInfoRole);
+                }
+            }
+        }
+        if(data.isValid()) {
+            auto info = data.value<std::shared_ptr<const Fm::FileInfo>>();
+            if(info) {
                 Q_EMIT clicked(ActivatedClick, info);
             }
         }
@@ -870,7 +983,11 @@ void FolderView::onClosingEditor(QWidget* editor, QAbstractItemDelegate::EndEdit
         QVariant data = index.model()->data(index, FolderModel::FileInfoRole);
         auto info = data.value<std::shared_ptr<const Fm::FileInfo>>();
         if (info) {
-            auto oldName = QString::fromStdString(info->name());
+            // NOTE: "Edit name" is used to handle invalid filename encoding.
+            auto oldName = QString::fromUtf8(g_file_info_get_edit_name(info->gFileInfo().get()));
+            if(oldName.isEmpty()) {
+                oldName = QString::fromStdString(info->name());
+            }
             if(newName == oldName) {
                 return;
             }
@@ -893,6 +1010,7 @@ void FolderView::setViewMode(ViewMode _mode) {
         smoothScrollTimer_->stop();
         delete smoothScrollTimer_;
         smoothScrollTimer_ = nullptr;
+        queuedScrollSteps_.clear(); // also forget the remaining steps
     }
     // FIXME: retain old selection
 
@@ -971,14 +1089,6 @@ void FolderView::setViewMode(ViewMode _mode) {
         delegate = new FolderItemDelegate(listView);
         delegate->setShadowHidden(shadowHidden_);
         listView->setItemDelegateForColumn(FolderModel::ColumnFileName, delegate);
-        // FIXME: should we expose the delegate?
-        listView->setMovement(QListView::Static);
-        /* If listView is already visible, setMovement() will lay out items again with delay
-           (see Qt, QListView::setMovement(), d->doDelayedItemsLayout()) and thus drop events
-           will remain disabled for the viewport. So, we should re-enable drop events here. */
-        if(listView->viewport()->isVisible()) {
-            listView->viewport()->setAcceptDrops(true);
-        }
         listView->setResizeMode(QListView::Adjust);
         listView->setWrapping(true);
         switch(mode) {
@@ -1023,9 +1133,7 @@ void FolderView::setViewMode(ViewMode _mode) {
         view->setDragDropMode(QAbstractItemView::DragDrop);
 
         // inline renaming
-        if(delegate) {
-            connect(delegate, &QAbstractItemDelegate::closeEditor, this, &FolderView::onClosingEditor);
-        }
+        connect(delegate, &QAbstractItemDelegate::closeEditor, this, &FolderView::onClosingEditor);
 
         if(model_) {
             // FIXME: preserve selections
@@ -1126,6 +1234,10 @@ void FolderView::setShadowHidden(bool shadowHidden) {
     }
 }
 
+void FolderView::setCtrlRightClick(bool ctrlRightClick) {
+    ctrlRightClick_ = ctrlRightClick;
+}
+
 FolderView::ViewMode FolderView::viewMode() const {
     return mode;
 }
@@ -1164,6 +1276,16 @@ bool FolderView::event(QEvent* event) {
     case QEvent::FontChange:
         updateGridSize();
         break;
+    case QEvent::KeyPress:
+        // Pressing Enter activates only the current index. With no current index,
+        // we activate the first selected index on pressing Enter (see onItemActivated).
+        if(view && !view->selectionModel()->currentIndex().isValid()) {
+            int k = static_cast<QKeyEvent*>(event)->key();
+            if(k == Qt::Key_Return || k == Qt::Key_Enter) {
+                onItemActivated(QModelIndex());
+            }
+        }
+        break;
     default:
         break;
     }
@@ -1195,7 +1317,8 @@ void FolderView::childMousePressEvent(QMouseEvent* event) {
 void FolderView::emitClickedAt(ClickType type, const QPoint& pos) {
     // indexAt() needs a point in "viewport" coordinates.
     QModelIndex index = view->indexAt(pos);
-    if(index.isValid()) {
+    if(index.isValid()
+       && (!ctrlRightClick_ || QApplication::keyboardModifiers() != Qt::ControlModifier)) {
         QVariant data = index.data(FolderModel::FileInfoRole);
         auto info = data.value<std::shared_ptr<const Fm::FileInfo>>();
         Q_EMIT clicked(type, info);
@@ -1327,21 +1450,7 @@ Fm::FileInfoList FolderView::selectedFiles() const {
 }
 
 void FolderView::selectAll() {
-    if(mode == DetailedListMode) {
-        view->selectAll();
-    }
-    else {
-        // NOTE: By default QListView::selectAll() selects all columns in the model.
-        // However, QListView only show the first column. Normal selection by mouse
-        // can only select the first column of every row. I consider this discripancy yet
-        // another design flaw of Qt. To make them consistent, we do it ourselves by only
-        // selecting the first column of every row and do not select all columns as Qt does.
-        // I'll report a Qt bug for this later.
-        if(model_) {
-            const QItemSelection sel{model_->index(0, 0), model_->index(model_->rowCount() - 1, 0)};
-            selectionModel()->select(sel, QItemSelectionModel::Select);
-        }
-    }
+    view->selectAll();
 }
 
 void FolderView::invertSelection() {
@@ -1362,7 +1471,7 @@ void FolderView::invertSelection() {
 
 void FolderView::childDragEnterEvent(QDragEnterEvent* event) {
     //qDebug("drag enter");
-    if(event->mimeData()->hasFormat("text/uri-list")) {
+    if(event->mimeData()->hasFormat(QStringLiteral("text/uri-list"))) {
         event->accept();
     }
     else {
@@ -1396,7 +1505,7 @@ void FolderView::childDropEvent(QDropEvent* e) {
     // NOTE: in theory, it's not possible to implement XDS with pure Qt.
     // We achieved this with some dirty XCB/XDND workarounds.
     // Please refer to XdndWorkaround::clientMessage() in xdndworkaround.cpp for details.
-    if(QX11Info::isPlatformX11() && e->mimeData()->hasFormat("XdndDirectSave0")) {
+    if(QX11Info::isPlatformX11() && e->mimeData()->hasFormat(QStringLiteral("XdndDirectSave0"))) {
         e->setDropAction(Qt::CopyAction);
         const QWidget* targetWidget = childView()->viewport();
         // these are dynamic QObject property set by our XDND workarounds in xdndworkaround.cpp.
@@ -1416,18 +1525,18 @@ void FolderView::childDropEvent(QDropEvent* e) {
                 QModelIndex index = view->indexAt(e->pos());
                 auto info = model_->fileInfoFromIndex(index);
                 if(info && info->isDir()) {
-                    filePath = info->path().child(basename);
+                    filePath = info->path().child(basename.constData());
                 }
             }
             if(!filePath.isValid()) {
-                filePath = path().child(basename);
+                filePath = path().child(basename.constData());
             }
             QByteArray fileUri = filePath.uri().get();
             XdndWorkaround::setWindowProperty(dndSource,  XdndDirectSaveAtom, textAtom, (void*)fileUri.constData(), fileUri.length());
 
             // 3. send to XDS selection data request with type "XdndDirectSave" to the source window and
             //    receive result from the source window. (S: success, E: error, or F: failure)
-            QByteArray result = e->mimeData()->data("XdndDirectSave0");
+            QByteArray result = e->mimeData()->data(QStringLiteral("XdndDirectSave0"));
             // NOTE: there seems to be some bugs in file-roller so it always replies with "E" even if the
             //       file extraction is finished successfully. Anyways, we ignore any error at the moment.
         }
@@ -1503,6 +1612,43 @@ bool FolderView::eventFilter(QObject* watched, QEvent* event) {
                     return true;
                 }
             }
+            // row-by-row scrolling when Shift is pressed
+            if((QApplication::keyboardModifiers() & Qt::ShiftModifier)
+                && (mode == CompactMode || mode == DetailedListMode)) // other modes have smooth scroling
+            {
+                QScrollBar *sbar = (mode == CompactMode ? view->horizontalScrollBar()
+                                                        : view->verticalScrollBar());
+                if(sbar != nullptr) {
+                    QWheelEvent *we = static_cast<QWheelEvent*>(event);
+#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
+                    QWheelEvent e(we->posF(),
+                                  we->globalPosF(),
+                                  we->pixelDelta(),
+#if (QT_VERSION < QT_VERSION_CHECK(5,14,0))
+                                  QPoint (0, we->angleDelta().y() / QApplication::wheelScrollLines()),
+#else
+                                  // the problem with horizontal wheel scrolling from inside view is fixed in Qt 5.14
+                                  mode == CompactMode
+                                    ? QPoint (we->angleDelta().y() / QApplication::wheelScrollLines(), 0)
+                                    : QPoint (0, we->angleDelta().y() / QApplication::wheelScrollLines()),
+#endif
+                                  we->buttons(),
+                                  Qt::NoModifier,
+                                  we->phase(),
+                                  false,
+                                  we->source());
+#else
+                    QWheelEvent e(we->posF(),
+                                  we->globalPosF(),
+                                  we->angleDelta().y() / QApplication::wheelScrollLines(),
+                                  we->buttons(),
+                                  Qt::NoModifier,
+                                  Qt::Vertical);
+#endif
+                    QApplication::sendEvent(sbar, &e);
+                    return true;
+                }
+            }
             // This is to fix #85: Scrolling doesn't work in compact view
             // Actually, I think it's the bug of Qt, not ours.
             // When in compact mode, only the horizontal scroll bar is used and the vertical one is hidden.
@@ -1510,34 +1656,32 @@ bool FolderView::eventFilter(QObject* watched, QEvent* event) {
             // Qt does not implement such a simple feature, unfortunately.
             // We do it by forwarding the scroll event in the viewport to the horizontal scrollbar.
             // FIXME: if someday Qt supports this, we have to disable the workaround.
-            if(mode == CompactMode) {
+            else if(mode == CompactMode) {
+#if (QT_VERSION < QT_VERSION_CHECK(5,14,0))
                 QScrollBar* scroll = view->horizontalScrollBar();
                 if(scroll) {
                     QApplication::sendEvent(scroll, event);
                     return true;
                 }
+#else
+                return false; // the problem with horizontal wheel scrolling from inside view is fixed in Qt 5.14
+#endif
             }
             // Smooth Scrolling
             // Some tricks are adapted from <https://github.com/zhou13/qsmoothscrollarea>.
             else if(mode != DetailedListMode
                     && event->spontaneous()
-                    && !(QApplication::keyboardModifiers() & (Qt::ShiftModifier | Qt::AltModifier))) {
+                    && static_cast<QWheelEvent*>(event)->source() == Qt::MouseEventNotSynthesized
+                    && !(QApplication::keyboardModifiers() & Qt::AltModifier)) {
                 if(QScrollBar* vbar = view->verticalScrollBar()) {
                     // keep track of the wheel event for smooth scrolling
-                    wheelEvent_ = static_cast<QWheelEvent*>(event);
-                    int delta = wheelEvent_->angleDelta().y();
+                    int delta = static_cast<QWheelEvent*>(event)->angleDelta().y();
+                    if(QApplication::keyboardModifiers() & Qt::ShiftModifier) {
+                        delta /= QApplication::wheelScrollLines(); // row-by-row scrolling
+                    }
                     if((delta > 0 && vbar->value() == vbar->minimum()) || (delta < 0 && vbar->value() == vbar->maximum())) {
                         break; // the scrollbar can't move
                     }
-                    // get a rough estimation of the wheel speed and disable animation if it's too high
-                    static QList<qint64> wheelEvents;
-                    wheelEvents << QDateTime::currentMSecsSinceEpoch();
-                    while(wheelEvents.last() - wheelEvents.first() > 500) {
-                        wheelEvents.removeFirst();
-                    }
-                    if(wheelEvents.size() > 10) {
-                        break;
-                    }
 
                     if(!smoothScrollTimer_) {
                         smoothScrollTimer_ = new QTimer();
@@ -1545,7 +1689,7 @@ bool FolderView::eventFilter(QObject* watched, QEvent* event) {
                     }
 
                     // set the data for smooth scrolling
-                    scollData data;
+                    scrollData data;
                     data.delta = delta;
                     data.leftFrames = scrollAnimFrames;
                     queuedScrollSteps_.append(data);
@@ -1562,30 +1706,56 @@ bool FolderView::eventFilter(QObject* watched, QEvent* event) {
 }
 
 void FolderView::scrollSmoothly() {
-    if(!wheelEvent_ || !view->verticalScrollBar()) {
+    if(!view->verticalScrollBar()) {
         return;
     }
 
     int totalDelta = 0;
-    QList<scollData>::iterator it = queuedScrollSteps_.begin();
+    QList<scrollData>::iterator it = queuedScrollSteps_.begin();
     while(it != queuedScrollSteps_.end()) {
-        if(it->leftFrames == 1) { // find the exact delta for the last frame
-            totalDelta += it->delta - (scrollAnimFrames - 1) * qRound((qreal)it->delta / (qreal)scrollAnimFrames);
+        int delta = qRound((qreal)it->delta / (qreal)scrollAnimFrames);
+        int remainingDelta = it->delta - (scrollAnimFrames - it->leftFrames) * delta;
+        if(qAbs(delta) >= qAbs(remainingDelta)) {
+            // this is the last frame or, due to rounding, there can be no more frame
+            totalDelta += remainingDelta;
             it = queuedScrollSteps_.erase(it);
         }
         else {
-            totalDelta += qRound((qreal)it->delta / (qreal)scrollAnimFrames);
+            totalDelta += delta;
             -- it->leftFrames;
             ++it;
         }
     }
     if(totalDelta != 0) {
-        // as in qevent.cpp -> QWheelEvent::QWheelEvent()
-        QWheelEvent e(wheelEvent_->pos(), wheelEvent_->globalPos(),
+#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
+        QWheelEvent e(QPointF(),
+                      QPointF(),
+                      QPoint(),
+                      QPoint (0, totalDelta),
+                      Qt::NoButton,
+                      Qt::NoModifier,
+                      Qt::NoScrollPhase,
+                      false);
+#else
+        QWheelEvent e(QPointF(),
+                      QPointF(),
                       totalDelta,
-                      wheelEvent_->buttons(), Qt::NoModifier, Qt::Vertical);
+                      Qt::NoButton,
+                      Qt::NoModifier,
+                      Qt::Vertical);
+#endif
         QApplication::sendEvent(view->verticalScrollBar(), &e);
     }
+
+    // update rubberband selection with smooth scrolling
+    if (QApplication::mouseButtons() & Qt::LeftButton) {
+        const QPoint globalPos = QCursor::pos();
+        QPoint pos = view->viewport()->mapFromGlobal(globalPos);
+        QMouseEvent ev(QEvent::MouseMove, pos, view->viewport()->mapTo(view->viewport()->topLevelWidget(), pos), globalPos,
+                       Qt::LeftButton, Qt::LeftButton, QApplication::keyboardModifiers());
+        QApplication::sendEvent(view->viewport(), &ev);
+    }
+
     if(queuedScrollSteps_.empty()) {
         smoothScrollTimer_->stop();
     }
@@ -1633,7 +1803,7 @@ void FolderView::onAutoSelectionTimeout() {
             int begin = current.row();
             int end = index.row();
             if(begin > end) {
-                qSwap(begin, end);
+                std::swap(begin, end);
             }
             for(int row = begin; row <= end; ++row) {
                 QModelIndex sel = model_->index(row, 0);
@@ -1711,35 +1881,6 @@ void FolderView::onFileClicked(int type, const std::shared_ptr<const Fm::FileInf
     }
 }
 
-void FolderView::onClipboardDataChange() {
-    if(model_) {
-        const QClipboard* clipboard = QApplication::clipboard();
-        const QMimeData* data = clipboard->mimeData();
-        Fm::FilePathList paths;
-        bool isCutSelection;
-        std::tie(paths, isCutSelection) = Fm::parseClipboardData(*data);
-        if(!folder()->path().hasUriScheme("search") // skip for search results
-           && isCutSelection
-           && Fm::isCurrentPidClipboardData(*data)) { // set cut files only with this app
-            auto cutDirPath = paths.size() > 0 ? paths[0].parent() : FilePath();
-            // set the cut file(s) only if the cutting is done here
-            if(folder()->path() == cutDirPath
-               && selectedFilePaths() == paths) {
-                model_->setCutFiles(selectionModel()->selection());
-            }
-            else if(folder()->hadCutFilesUnset() || folder()->hasCutFiles()) {
-                model_->setCutFiles(QItemSelection());
-            }
-            return;
-        }
-
-        folder()->setCutFiles(std::make_shared<HashSet>()); // clean Folder::cutFilesHashSet_
-        if(folder()->hadCutFilesUnset()) {
-            model_->setCutFiles(QItemSelection()); // update indexes if there were cut files here
-        }
-    }
-}
-
 void FolderView::prepareFileMenu(FileMenu* /*menu*/) {
 }
 
