@@ -261,9 +261,13 @@ void PathBar::setPath(Fm::FilePath path) {
             name = btnPath.toString();
         }
         else {
-            name = btnPath.baseName();
+            displayName = btnPath.baseName();
+            // "name" is used for making the path from its components in PathBar::pathForButton().
+            // So, it should be extracted from g_file_get_parse_name().
+            // (In places like trash:///, FilePath::baseName() cannot be used to make a full path.)
+            name = CStrPtr{g_path_get_basename(btnPath.displayName().get())};
         }
-        auto btn = new PathButton(name.get(), displayName ? displayName.get() : name.get(), isRoot, buttonsWidget_);
+        auto btn = new PathButton(name.get(), QString::fromUtf8(displayName.get()), isRoot, buttonsWidget_);
         btn->show();
         connect(btn, &QAbstractButton::toggled, this, &PathBar::onButtonToggled);
         buttonsLayout_->insertWidget(0, btn);
@@ -298,7 +302,7 @@ void PathBar::openEditor() {
         scrollArea_->hide();
         scrollToStart_->setVisible(false);
         scrollToEnd_->setVisible(false);
-        tempPathEdit_->setText(currentPath_.toString().get());
+        tempPathEdit_->setText(QString::fromUtf8(currentPath_.toString().get()));
 
         connect(tempPathEdit_, &PathEdit::returnPressed, this, &PathBar::onReturnPressed);
         connect(tempPathEdit_, &PathEdit::editingFinished, this, &PathBar::closeEditor);
@@ -333,7 +337,7 @@ void PathBar::closeEditor() {
 }
 
 void PathBar::copyPath() {
-    QApplication::clipboard()->setText(currentPath_.toString().get());
+    QApplication::clipboard()->setText(QString::fromUtf8(currentPath_.toString().get()));
 }
 
 void PathBar::onReturnPressed() {
