@@ -28,6 +28,7 @@
 #include <QHeaderView>
 #include <QDebug>
 #include <QGuiApplication>
+#include <QTimer>
 #include "folderitemdelegate.h"
 
 namespace Fm {
@@ -85,31 +86,31 @@ bool PlacesProxyModel::filterAcceptsRow(int source_row, const QModelIndex& sourc
         if(PlacesModelItem* item = static_cast<PlacesModelItem*>(srcModel->itemFromIndex(index))) {
             if(item->type() == PlacesModelItem::Places) {
                 if(auto path = item->path()) {
-                    if(hidden_.contains(path.toString().get())) {
+                    if(hidden_.contains(QString::fromUtf8(path.toString().get()))) {
                         return false;
                     }
                 }
             }
             else if(item->type() == PlacesModelItem::Volume) {
                 CStrPtr uuid{g_volume_get_uuid(static_cast<PlacesModelVolumeItem*>(item)->volume())};
-                if(uuid && hidden_.contains(uuid.get())) {
+                if(uuid && hidden_.contains(QString::fromUtf8(uuid.get()))) {
                     return false;
                 }
             }
             // show a root items only if, at least, one of its children is shown
             else if((source_row == 0 || source_row == 1) && !source_parent.isValid()) {
-                QModelIndex indx = index.child(0, 0);
+                QModelIndex indx = index.model()->index(0, 0, index);
                 while(PlacesModelItem* childItem = static_cast<PlacesModelItem*>(srcModel->itemFromIndex(indx))) {
                     if(childItem->type() == PlacesModelItem::Places) {
                         if(auto path = childItem->path()) {
-                            if(!hidden_.contains(path.toString().get())) {
+                            if(!hidden_.contains(QString::fromUtf8(path.toString().get()))) {
                                 return true;
                             }
                         }
                     }
                     else if(childItem->type() == PlacesModelItem::Volume) {
                         CStrPtr uuid{g_volume_get_uuid(static_cast<PlacesModelVolumeItem*>(childItem)->volume())};
-                        if(uuid == nullptr || !hidden_.contains(uuid.get())) {
+                        if(uuid == nullptr || !hidden_.contains(QString::fromUtf8(uuid.get()))) {
                             return true;
                         }
                     }
@@ -157,11 +158,15 @@ PlacesView::PlacesView(QWidget* parent):
         // for some reason (a Qt bug?), spanning is reset
         spanFirstColumn();
     });
-    connect(model_.get(), &QAbstractItemModel::rowsRemoved, this, [this](const QModelIndex&, int, int) {
+    connect(model_.get(), &QAbstractItemModel::rowsRemoved, this, [](const QModelIndex&, int, int) {
         proxyModel_->setHidden(QString());
     });
 
     QHeaderView* headerView = header();
+    // WARNING: Since Qt 5.11, if the minimum header section width isn't set,
+    // Qt will set it by considering the font size, even without text.
+    // See Qt doc and https://bugreports.qt.io/browse/QTBUG-68503
+    headerView->setMinimumSectionSize(1);
     headerView->setSectionResizeMode(0, QHeaderView::Stretch);
     headerView->setSectionResizeMode(1, QHeaderView::Fixed);
     headerView->setStretchLastSection(false);
@@ -178,9 +183,7 @@ PlacesView::PlacesView(QWidget* parent):
 
     // update the umount button's column width based on icon size
     onIconSizeChanged(iconSize());
-#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0) // this signal requires Qt >= 5.5
     connect(this, &QAbstractItemView::iconSizeChanged, this, &PlacesView::onIconSizeChanged);
-#endif
 }
 
 PlacesView::~PlacesView() {
@@ -224,18 +227,24 @@ void PlacesView::activateRow(int type, const QModelIndex& index) {
                     GVolume* volume = volumeItem->volume();
                     MountOperation* op = new MountOperation(true, this);
                     op->mount(volume);
-                    // connect(op, SIGNAL(finished(GError*)), SLOT(onMountOperationFinished(GError*)));
-                    // blocking here until the mount operation is finished?
-
-                    // FIXME: update status of the volume after mount is finished!!
-                    if(!op->wait()) {
-                        return;
-                    }
-                    path = item->path();
+                    // WARNING: "QAbstractItemView::mouseReleaseEvent" will be dispatched only
+                    // after this function returns. Therefore, without a single-shot timer, if
+                    // the window is closed before the mount operation is finished, the operation
+                    // will be canceled, this function will return and "mouseReleaseEvent" will
+                    // be sent to a destroyed QAbstractItemView, resulting in a crash.
+                    QTimer::singleShot(0, op, [this, op, type, index] () {
+                        if(op->wait()) {
+                            if(PlacesModelItem* item = static_cast<PlacesModelItem*>(model_->itemFromIndex(proxyModel_->mapToSource(index)))) {
+                                if(auto path = item->path()) {
+                                    Q_EMIT chdirRequested(type, path);
+                                }
+                            }
+                        }
+                    });
                 }
             }
         }
-        if(path) {
+        else {
             Q_EMIT chdirRequested(type, path);
         }
     }
@@ -251,7 +260,8 @@ void PlacesView::onPressed(const QModelIndex& index) {
 }
 
 void PlacesView::onIconSizeChanged(const QSize& size) {
-    setColumnWidth(1, size.width() + 5);
+    setColumnWidth(1, size.width() + 2 * (style()->pixelMetric(QStyle::PM_FocusFrameHMargin)
+                                            + 1)); // put it inside the focus rectangle, if any
 }
 
 void PlacesView::onEjectButtonClicked(PlacesModelItem* item) {
@@ -318,15 +328,6 @@ void PlacesView::setCurrentPath(Fm::FilePath path) {
 
 void PlacesView::dragMoveEvent(QDragMoveEvent* event) {
     QTreeView::dragMoveEvent(event);
-    /*
-    QModelIndex index = indexAt(event->pos());
-    if(event->isAccepted() && index.isValid() && index.parent() == model_->bookmarksRoot->index()) {
-      if(dropIndicatorPosition() != OnItem) {
-        event->setDropAction(Qt::LinkAction);
-        event->accept();
-      }
-    }
-    */
 }
 
 void PlacesView::dropEvent(QDropEvent* event) {
@@ -518,7 +519,7 @@ void PlacesView::contextMenuEvent(QContextMenuEvent* event) {
                 // add a "Hide" action to the end
                 menu->addSeparator();
                 action = new PlacesModel::ItemAction(item->index(), tr("Hide"), menu);
-                QString pathStr(path_str.get());
+                QString pathStr(QString::fromUtf8(path_str.get()));
                 action->setCheckable(true);
                 if(proxyModel_->isShowingAll()) {
                     action->setChecked(proxyModel_->isHidden(pathStr));
@@ -572,7 +573,7 @@ void PlacesView::contextMenuEvent(QContextMenuEvent* event) {
             // add a "Hide" action to the end
             CStrPtr uuid{g_volume_get_uuid(static_cast<PlacesModelVolumeItem*>(item)->volume())};
             if(uuid) {
-                QString str = uuid.get();
+                QString str = QString::fromUtf8(uuid.get());
                 menu->addSeparator();
                 action = new PlacesModel::ItemAction(item->index(), tr("Hide"), menu);
                 action->setCheckable(true);
@@ -619,6 +620,35 @@ void PlacesView::contextMenuEvent(QContextMenuEvent* event) {
     }
 }
 
+void PlacesView::keyPressEvent(QKeyEvent* event) {
+    // prevent propagation of usual modifiers because
+    // they might be used elsewhere in shortcuts, especially with arrow keys
+    if(event->modifiers() & (Qt::ShiftModifier | Qt::ControlModifier | Qt::AltModifier | Qt::MetaModifier)) {
+        return;
+    }
+    // activate child items and expand/collapse root items with Enter/Return
+    if(event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter) {
+        QModelIndex index = currentIndex();
+        if(index.isValid()) {
+            if (index.column() != 0) {
+                index = index.sibling(index.row(), 0); // the real item is at column 0
+            }
+            if (index.isValid()) {
+                if (!index.parent().isValid()) { // root item
+                    setExpanded(index, !isExpanded(index));
+                }
+                else {
+                    // may have not been selected yet
+                    selectionModel()->select(index, QItemSelectionModel::SelectCurrent | QItemSelectionModel::Rows);
+                    activateRow(0, index);
+                }
+                return;
+            }
+        }
+    }
+    QTreeView::keyPressEvent(event);
+}
+
 void PlacesView::restoreHiddenItems(const QSet<QString>& items) {
     proxyModel_->restoreHiddenItems(items);
 }
