@@ -41,8 +41,7 @@ SidePane::SidePane(QWidget* parent):
     verticalLayout->setContentsMargins(0, 0, 0, 0);
 
     combo_ = new QComboBox(this);
-    combo_->setFrame(false);
-    combo_->addItem(tr("Places"));
+    combo_->addItem(tr("Lists")); // "Places" is already used in PlacesModel
     combo_->addItem(tr("Directory Tree"));
     connect(combo_, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &SidePane::onComboCurrentIndexChanged);
     verticalLayout->addWidget(combo_);
@@ -139,6 +138,13 @@ void SidePane::initDirTree() {
     rootPaths.emplace_back(Fm::FilePath::fromLocalPath("/"));
     model->addRoots(std::move(rootPaths));
     static_cast<DirTreeView*>(view_)->setModel(model);
+    // wait for the roots to be added and only then set the current path
+    connect(model, &DirTreeModel::rootsAdded, view_, [this] {
+        if(mode_ == ModeDirTree) {
+            DirTreeView* dirTreeView = static_cast<DirTreeView*>(view_);
+            dirTreeView->setCurrentPath(currentPath_);
+        }
+    });
 }
 
 void SidePane::setMode(Mode mode) {
@@ -180,7 +186,6 @@ void SidePane::setMode(Mode mode) {
         view_ = dirTreeView;
         initDirTree();
         dirTreeView->setIconSize(iconSize_);
-        dirTreeView->setCurrentPath(currentPath_);
         connect(dirTreeView, &DirTreeView::chdirRequested, this, &SidePane::chdirRequested);
         connect(dirTreeView, &DirTreeView::openFolderInNewWindowRequested,
                 this, &SidePane::openFolderInNewWindowRequested);
