@@ -120,8 +120,8 @@
     <name>FileDialog</name>
     <message>
         <location filename="../filedialog.ui" line="22"/>
-        <source>Location:</source>
-        <translation></translation>
+        <source>Path:</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../filedialog.ui" line="65"/>
@@ -230,88 +230,88 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="317"/>
+        <location filename="../file-props.ui" line="336"/>
         <source>Device Usage:</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="349"/>
+        <location filename="../file-props.ui" line="346"/>
         <source>Permissions</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="364"/>
+        <location filename="../file-props.ui" line="361"/>
         <source>Ownership</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="388"/>
-        <location filename="../file-props.ui" line="453"/>
-        <location filename="../file-props.ui" line="567"/>
+        <location filename="../file-props.ui" line="385"/>
+        <location filename="../file-props.ui" line="450"/>
+        <location filename="../file-props.ui" line="564"/>
         <source>Group:</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="401"/>
-        <location filename="../file-props.ui" line="436"/>
-        <location filename="../file-props.ui" line="515"/>
+        <location filename="../file-props.ui" line="398"/>
+        <location filename="../file-props.ui" line="433"/>
+        <location filename="../file-props.ui" line="512"/>
         <source>Owner:</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="417"/>
+        <location filename="../file-props.ui" line="414"/>
         <source>Access Control</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="470"/>
-        <location filename="../file-props.ui" line="619"/>
+        <location filename="../file-props.ui" line="467"/>
+        <location filename="../file-props.ui" line="616"/>
         <source>Other:</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="487"/>
+        <location filename="../file-props.ui" line="484"/>
         <source>Make the file executable</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="528"/>
-        <location filename="../file-props.ui" line="580"/>
-        <location filename="../file-props.ui" line="632"/>
+        <location filename="../file-props.ui" line="525"/>
+        <location filename="../file-props.ui" line="577"/>
+        <location filename="../file-props.ui" line="629"/>
         <source>Read</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="541"/>
-        <location filename="../file-props.ui" line="593"/>
-        <location filename="../file-props.ui" line="645"/>
+        <location filename="../file-props.ui" line="538"/>
+        <location filename="../file-props.ui" line="590"/>
+        <location filename="../file-props.ui" line="642"/>
         <source>Write</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="554"/>
-        <location filename="../file-props.ui" line="606"/>
-        <location filename="../file-props.ui" line="658"/>
+        <location filename="../file-props.ui" line="551"/>
+        <location filename="../file-props.ui" line="603"/>
+        <location filename="../file-props.ui" line="655"/>
         <source>Execute</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="667"/>
+        <location filename="../file-props.ui" line="664"/>
         <source>Sticky</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="674"/>
+        <location filename="../file-props.ui" line="671"/>
         <source>SetUID</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="681"/>
+        <location filename="../file-props.ui" line="678"/>
         <source>SetGID</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="717"/>
+        <location filename="../file-props.ui" line="714"/>
         <source>Advanced Mode</source>
         <translation></translation>
     </message>
@@ -327,7 +327,7 @@
 <context>
     <name>Fm::AppChooserDialog</name>
     <message>
-        <location filename="../appchooserdialog.cpp" line="263"/>
+        <location filename="../appchooserdialog.cpp" line="262"/>
         <source>Select an application to open &quot;%1&quot; files</source>
         <translation></translation>
     </message>
@@ -335,12 +335,12 @@
 <context>
     <name>Fm::CreateNewMenu</name>
     <message>
-        <location filename="../createnewmenu.cpp" line="61"/>
+        <location filename="../createnewmenu.cpp" line="62"/>
         <source>Folder</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../createnewmenu.cpp" line="65"/>
+        <location filename="../createnewmenu.cpp" line="66"/>
         <source>Blank File</source>
         <translation></translation>
     </message>
@@ -348,7 +348,7 @@
 <context>
     <name>Fm::DirListJob</name>
     <message>
-        <location filename="../core/dirlistjob.cpp" line="46"/>
+        <location filename="../core/dirlistjob.cpp" line="48"/>
         <source>The specified directory &apos;%1&apos; is not valid</source>
         <translation></translation>
     </message>
@@ -371,17 +371,17 @@
 <context>
     <name>Fm::DirTreeView</name>
     <message>
-        <location filename="../dirtreeview.cpp" line="211"/>
+        <location filename="../dirtreeview.cpp" line="213"/>
         <source>Open in New T&amp;ab</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../dirtreeview.cpp" line="215"/>
+        <location filename="../dirtreeview.cpp" line="217"/>
         <source>Open in New Win&amp;dow</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../dirtreeview.cpp" line="220"/>
+        <location filename="../dirtreeview.cpp" line="222"/>
         <source>Open in Termina&amp;l</source>
         <translation></translation>
     </message>
@@ -412,7 +412,7 @@
 <context>
     <name>Fm::EditBookmarksDialog</name>
     <message>
-        <location filename="../editbookmarksdialog.cpp" line="92"/>
+        <location filename="../editbookmarksdialog.cpp" line="94"/>
         <source>New bookmark</source>
         <translation></translation>
     </message>
@@ -440,109 +440,109 @@ What do you want to do with it?</source>
 <context>
     <name>Fm::FileDialog</name>
     <message>
-        <location filename="../filedialog.cpp" line="102"/>
+        <location filename="../filedialog.cpp" line="104"/>
         <source>Go Back</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="103"/>
+        <location filename="../filedialog.cpp" line="105"/>
         <source>Alt+Left</source>
         <comment>Go Back</comment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="109"/>
+        <location filename="../filedialog.cpp" line="111"/>
         <source>Go Forward</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="110"/>
+        <location filename="../filedialog.cpp" line="112"/>
         <source>Alt+Right</source>
         <comment>Go Forward</comment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="117"/>
+        <location filename="../filedialog.cpp" line="119"/>
         <source>Reload</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="118"/>
+        <location filename="../filedialog.cpp" line="120"/>
         <source>F5</source>
         <comment>Reload</comment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="135"/>
+        <location filename="../filedialog.cpp" line="137"/>
         <source>Create Folder</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="142"/>
+        <location filename="../filedialog.cpp" line="144"/>
         <source>Icon View</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="146"/>
+        <location filename="../filedialog.cpp" line="148"/>
         <source>Thumbnail View</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="150"/>
+        <location filename="../filedialog.cpp" line="152"/>
         <source>Compact View</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="154"/>
+        <location filename="../filedialog.cpp" line="156"/>
         <source>Detailed List View</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="271"/>
-        <location filename="../filedialog.cpp" line="634"/>
+        <location filename="../filedialog.cpp" line="300"/>
+        <location filename="../filedialog.cpp" line="690"/>
         <source>Error</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="271"/>
+        <location filename="../filedialog.cpp" line="300"/>
         <source>Please select a file</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="295"/>
+        <location filename="../filedialog.cpp" line="342"/>
         <source>%1 already exists.
 Do you want to replace it?</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="604"/>
+        <location filename="../filedialog.cpp" line="660"/>
         <source>Path &quot;%1&quot; does not exist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="618"/>
+        <location filename="../filedialog.cpp" line="674"/>
         <source>&quot;%1&quot; is not a directory</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="624"/>
+        <location filename="../filedialog.cpp" line="680"/>
         <source>&quot;%1&quot; is not a file</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="751"/>
-        <location filename="../filedialog.cpp" line="859"/>
+        <location filename="../filedialog.cpp" line="823"/>
+        <location filename="../filedialog.cpp" line="931"/>
         <source>&amp;Open</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="754"/>
-        <location filename="../filedialog.cpp" line="867"/>
+        <location filename="../filedialog.cpp" line="826"/>
+        <location filename="../filedialog.cpp" line="939"/>
         <source>&amp;Save</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="761"/>
+        <location filename="../filedialog.cpp" line="833"/>
         <source>All Files (*)</source>
         <translation></translation>
     </message>
@@ -604,7 +604,7 @@ Do you want to replace it?</source>
     </message>
     <message>
         <location filename="../filemenu.cpp" line="159"/>
-        <location filename="../filemenu.cpp" line="406"/>
+        <location filename="../filemenu.cpp" line="407"/>
         <source>&amp;Move to Trash</source>
         <translation></translation>
     </message>
@@ -614,42 +614,42 @@ Do you want to replace it?</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="217"/>
+        <location filename="../filemenu.cpp" line="218"/>
         <source>Extract to...</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="225"/>
+        <location filename="../filemenu.cpp" line="226"/>
         <source>Extract Here</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="232"/>
+        <location filename="../filemenu.cpp" line="233"/>
         <source>Compress</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="241"/>
+        <location filename="../filemenu.cpp" line="242"/>
         <source>Properties</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="252"/>
+        <location filename="../filemenu.cpp" line="253"/>
         <source>Trust selected executables</source>
         <translation>Trust selected executable(s)</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="253"/>
+        <location filename="../filemenu.cpp" line="254"/>
         <source>Trust this executable</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="341"/>
+        <location filename="../filemenu.cpp" line="342"/>
         <source>Output</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="406"/>
+        <location filename="../filemenu.cpp" line="407"/>
         <source>&amp;Delete</source>
         <translation></translation>
     </message>
@@ -657,30 +657,30 @@ Do you want to replace it?</source>
 <context>
     <name>Fm::FileOperation</name>
     <message>
-        <location filename="../fileoperation.cpp" line="309"/>
+        <location filename="../fileoperation.cpp" line="312"/>
         <source>Error</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../fileoperation.cpp" line="310"/>
+        <location filename="../fileoperation.cpp" line="313"/>
         <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
 Do you want to delete them instead?</source>
         <translation>Some files cannot be moved to trash can because the underlying file-systems don&apos;t support this operation.
 Do you want to delete them instead?</translation>
     </message>
     <message>
-        <location filename="../fileoperation.cpp" line="375"/>
-        <location filename="../fileoperation.cpp" line="392"/>
+        <location filename="../fileoperation.cpp" line="399"/>
+        <location filename="../fileoperation.cpp" line="417"/>
         <source>Confirm</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../fileoperation.cpp" line="376"/>
+        <location filename="../fileoperation.cpp" line="400"/>
         <source>Do you want to delete the selected files?</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../fileoperation.cpp" line="393"/>
+        <location filename="../fileoperation.cpp" line="418"/>
         <source>Do you want to move the selected files to trash can?</source>
         <translation></translation>
     </message>
@@ -802,47 +802,50 @@ Do you want to delete them instead?</translation>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filepropsdialog.cpp" line="333"/>
+        <location filename="../filepropsdialog.cpp" line="336"/>
         <source>%p% used</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filepropsdialog.cpp" line="334"/>
+        <location filename="../filepropsdialog.cpp" line="337"/>
         <source>%1 Free of %2</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filepropsdialog.cpp" line="378"/>
+        <location filename="../filepropsdialog.cpp" line="382"/>
         <source>no file</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filepropsdialog.cpp" line="380"/>
+        <location filename="../filepropsdialog.cpp" line="384"/>
         <source>one file</source>
         <translation></translation>
     </message>
-    <message>
-        <location filename="../filepropsdialog.cpp" line="382"/>
-        <source>%1 files</source>
-        <translation></translation>
+    <message numerus="yes">
+        <location filename="../filepropsdialog.cpp" line="386"/>
+        <source>%Ln files</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
     </message>
     <message>
-        <location filename="../filepropsdialog.cpp" line="416"/>
+        <location filename="../filepropsdialog.cpp" line="420"/>
         <source>Select an icon</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filepropsdialog.cpp" line="418"/>
+        <location filename="../filepropsdialog.cpp" line="422"/>
         <source>Images (*.png *.xpm *.svg *.svgz )</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filepropsdialog.cpp" line="514"/>
+        <location filename="../filepropsdialog.cpp" line="518"/>
         <source>Apply changes</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filepropsdialog.cpp" line="515"/>
+        <location filename="../filepropsdialog.cpp" line="519"/>
         <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
         <translation></translation>
     </message>
@@ -868,7 +871,12 @@ Do you want to delete them instead?</translation>
 <context>
     <name>Fm::FileTransferJob</name>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="497"/>
+        <location filename="../core/filetransferjob.cpp" line="471"/>
+        <source>Cannot copy a directory into itself!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../core/filetransferjob.cpp" line="522"/>
         <source>Cannot create a link on non-native filesystem</source>
         <translation>Cannot create a link on non-native file-system</translation>
     </message>
@@ -906,12 +914,12 @@ Do you want to delete them instead?</translation>
         <translation></translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="97"/>
+        <location filename="../foldermenu.cpp" line="98"/>
         <source>Folder Pr&amp;operties</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="140"/>
+        <location filename="../foldermenu.cpp" line="141"/>
         <source>Output</source>
         <translation></translation>
     </message>
@@ -926,20 +934,30 @@ Do you want to delete them instead?</translation>
         <translation></translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="165"/>
+        <location filename="../foldermenu.cpp" line="167"/>
+        <source>By Deletion Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../foldermenu.cpp" line="170"/>
         <source>By File Size</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="166"/>
+        <location filename="../foldermenu.cpp" line="171"/>
         <source>By File Type</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="167"/>
+        <location filename="../foldermenu.cpp" line="172"/>
         <source>By File Owner</source>
         <translation></translation>
     </message>
+    <message>
+        <location filename="../foldermenu.cpp" line="173"/>
+        <source>By File Group</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../foldermenu.cpp" line="179"/>
         <source>Ascending</source>
@@ -956,7 +974,12 @@ Do you want to delete them instead?</translation>
         <translation></translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="211"/>
+        <location filename="../foldermenu.cpp" line="209"/>
+        <source>Hidden Last</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../foldermenu.cpp" line="217"/>
         <source>Case Sensitive</source>
         <translation></translation>
     </message>
@@ -964,36 +987,89 @@ Do you want to delete them instead?</translation>
 <context>
     <name>Fm::FolderModel</name>
     <message>
-        <location filename="../foldermodel.cpp" line="275"/>
+        <location filename="../foldermodel.cpp" line="274"/>
+        <source>Location:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../foldermodel.cpp" line="277"/>
+        <source>File type:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../foldermodel.cpp" line="281"/>
+        <source>File size:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../foldermodel.cpp" line="285"/>
+        <source>Last modified:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../foldermodel.cpp" line="286"/>
+        <source>Last accessed:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../foldermodel.cpp" line="290"/>
+        <source>Owner:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../foldermodel.cpp" line="291"/>
+        <source>Group:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../foldermodel.cpp" line="359"/>
         <source>Name</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="278"/>
+        <location filename="../foldermodel.cpp" line="362"/>
         <source>Type</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="281"/>
+        <location filename="../foldermodel.cpp" line="365"/>
         <source>Size</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="284"/>
+        <location filename="../foldermodel.cpp" line="368"/>
         <source>Modified</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="287"/>
+        <location filename="../foldermodel.cpp" line="371"/>
+        <source>Deleted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../foldermodel.cpp" line="374"/>
         <source>Owner</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="290"/>
+        <location filename="../foldermodel.cpp" line="377"/>
         <source>Group</source>
         <translation></translation>
     </message>
 </context>
+<context>
+    <name>Fm::FolderViewTreeView</name>
+    <message>
+        <location filename="../folderview.cpp" line="395"/>
+        <source>Auto-resize columns</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../folderview.cpp" line="412"/>
+        <source>Visible Columns</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>Fm::FontButton</name>
     <message>
@@ -1031,42 +1107,42 @@ Do you want to delete them instead?</translation>
 <context>
     <name>Fm::PlacesModel</name>
     <message>
-        <location filename="../placesmodel.cpp" line="45"/>
+        <location filename="../placesmodel.cpp" line="47"/>
         <source>Places</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesmodel.cpp" line="53"/>
+        <location filename="../placesmodel.cpp" line="55"/>
         <source>Desktop</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesmodel.cpp" line="59"/>
+        <location filename="../placesmodel.cpp" line="61"/>
         <source>Computer</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesmodel.cpp" line="67"/>
+        <location filename="../placesmodel.cpp" line="69"/>
         <source>Applications</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesmodel.cpp" line="76"/>
+        <location filename="../placesmodel.cpp" line="78"/>
         <source>Network</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesmodel.cpp" line="80"/>
+        <location filename="../placesmodel.cpp" line="82"/>
         <source>Devices</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesmodel.cpp" line="134"/>
+        <location filename="../placesmodel.cpp" line="136"/>
         <source>Bookmarks</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesmodel.cpp" line="225"/>
+        <location filename="../placesmodel.cpp" line="227"/>
         <source>Trash</source>
         <translation></translation>
     </message>
@@ -1074,64 +1150,64 @@ Do you want to delete them instead?</translation>
 <context>
     <name>Fm::PlacesView</name>
     <message>
-        <location filename="../placesview.cpp" line="485"/>
+        <location filename="../placesview.cpp" line="486"/>
         <source>Open in New Tab</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="488"/>
+        <location filename="../placesview.cpp" line="489"/>
         <source>Open in New Window</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="500"/>
+        <location filename="../placesview.cpp" line="501"/>
         <source>Empty Trash</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="520"/>
-        <location filename="../placesview.cpp" line="577"/>
+        <location filename="../placesview.cpp" line="521"/>
+        <location filename="../placesview.cpp" line="578"/>
         <source>Hide</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="537"/>
+        <location filename="../placesview.cpp" line="538"/>
         <source>Move Bookmark Up</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="542"/>
+        <location filename="../placesview.cpp" line="543"/>
         <source>Move Bookmark Down</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="546"/>
+        <location filename="../placesview.cpp" line="547"/>
         <source>Rename Bookmark</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="549"/>
+        <location filename="../placesview.cpp" line="550"/>
         <source>Remove Bookmark</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="558"/>
-        <location filename="../placesview.cpp" line="591"/>
+        <location filename="../placesview.cpp" line="559"/>
+        <location filename="../placesview.cpp" line="592"/>
         <source>Unmount</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="562"/>
+        <location filename="../placesview.cpp" line="563"/>
         <source>Mount</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="568"/>
+        <location filename="../placesview.cpp" line="569"/>
         <source>Eject</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="603"/>
+        <location filename="../placesview.cpp" line="604"/>
         <source>Show All Entries</source>
         <translation></translation>
     </message>
@@ -1140,7 +1216,7 @@ Do you want to delete them instead?</translation>
     <name>Fm::RenameDialog</name>
     <message>
         <location filename="../renamedialog.cpp" line="58"/>
-        <location filename="../renamedialog.cpp" line="78"/>
+        <location filename="../renamedialog.cpp" line="77"/>
         <source>Type: %1
 Size: %2
 Modified: %3</source>
@@ -1148,18 +1224,18 @@ Modified: %3</source>
     </message>
     <message>
         <location filename="../renamedialog.cpp" line="64"/>
-        <location filename="../renamedialog.cpp" line="84"/>
+        <location filename="../renamedialog.cpp" line="83"/>
         <source>Type: %1
 Modified: %2</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../renamedialog.cpp" line="97"/>
+        <location filename="../renamedialog.cpp" line="96"/>
         <source>&amp;Overwrite</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../renamedialog.cpp" line="99"/>
+        <location filename="../renamedialog.cpp" line="98"/>
         <source>&amp;Rename</source>
         <translation></translation>
     </message>
@@ -1167,12 +1243,12 @@ Modified: %2</source>
 <context>
     <name>Fm::SidePane</name>
     <message>
-        <location filename="../sidepane.cpp" line="45"/>
-        <source>Places</source>
-        <translation></translation>
+        <location filename="../sidepane.cpp" line="44"/>
+        <source>Lists</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sidepane.cpp" line="46"/>
+        <location filename="../sidepane.cpp" line="45"/>
         <source>Directory Tree</source>
         <translation></translation>
     </message>
@@ -1224,8 +1300,8 @@ Modified: %2</source>
     </message>
     <message>
         <location filename="../mount-operation-password.ui" line="137"/>
-        <source>Remember password until you &amp;logout</source>
-        <translation></translation>
+        <source>Remember password for &amp;this session</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mount-operation-password.ui" line="147"/>
@@ -1236,61 +1312,61 @@ Modified: %2</source>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../utilities.cpp" line="178"/>
+        <location filename="../utilities.cpp" line="171"/>
         <source>Rename File</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="179"/>
+        <location filename="../utilities.cpp" line="172"/>
         <source>Please enter a new name:</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filelauncher.cpp" line="101"/>
-        <location filename="../filepropsdialog.cpp" line="539"/>
+        <location filename="../filelauncher.cpp" line="104"/>
+        <location filename="../filepropsdialog.cpp" line="543"/>
         <location filename="../mountoperation.cpp" line="207"/>
-        <location filename="../utilities.cpp" line="169"/>
-        <location filename="../utilities.cpp" line="263"/>
+        <location filename="../utilities.cpp" line="155"/>
+        <location filename="../utilities.cpp" line="260"/>
         <source>Error</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="204"/>
+        <location filename="../utilities.cpp" line="200"/>
         <source>Create Folder</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="205"/>
+        <location filename="../utilities.cpp" line="201"/>
         <source>Create File</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="209"/>
+        <location filename="../utilities.cpp" line="205"/>
         <source>Please enter a new file name:</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="210"/>
+        <location filename="../utilities.cpp" line="206"/>
         <source>New text file</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="214"/>
+        <location filename="../utilities.cpp" line="210"/>
         <source>Please enter a new folder name:</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="215"/>
+        <location filename="../utilities.cpp" line="211"/>
         <source>New folder</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="220"/>
+        <location filename="../utilities.cpp" line="216"/>
         <source>Enter a name for the new %1:</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../filepropsdialog.cpp" line="556"/>
+        <location filename="../filepropsdialog.cpp" line="560"/>
         <source>Custom Icon Error</source>
         <translation></translation>
     </message>
@@ -1300,17 +1376,17 @@ Modified: %2</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../core/basicfilelauncher.cpp" line="272"/>
+        <location filename="../core/basicfilelauncher.cpp" line="288"/>
         <source>Invalid desktop entry file: &apos;%1&apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../core/basicfilelauncher.cpp" line="307"/>
+        <location filename="../core/basicfilelauncher.cpp" line="324"/>
         <source>No default application is set to launch &apos;%1&apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../core/basicfilelauncher.cpp" line="348"/>
+        <location filename="../core/basicfilelauncher.cpp" line="365"/>
         <source>Cannot set working directory to &apos;%1&apos;: %2</source>
         <translation></translation>
     </message>
@@ -1332,31 +1408,11 @@ Modified: %2</source>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation></translation>
     </message>
-    <message>
-        <location filename="../rename-dialog.ui" line="56"/>
-        <source>dest</source>
-        <translation></translation>
-    </message>
     <message>
         <location filename="../rename-dialog.ui" line="63"/>
         <source>with the following file?</source>
         <translation></translation>
     </message>
-    <message>
-        <location filename="../rename-dialog.ui" line="76"/>
-        <source>src file info</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../rename-dialog.ui" line="89"/>
-        <source>dest file info</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../rename-dialog.ui" line="102"/>
-        <source>src</source>
-        <translation></translation>
-    </message>
     <message>
         <location filename="../rename-dialog.ui" line="122"/>
         <source>&amp;File name:</source>
@@ -1415,11 +1471,6 @@ Modified: %2</source>
         <source>&amp;Remove</source>
         <translation></translation>
     </message>
-    <message>
-        <location filename="../filesearch.ui" line="122"/>
-        <source>Search in sub directories</source>
-        <translation></translation>
-    </message>
     <message>
         <location filename="../filesearch.ui" line="129"/>
         <source>Search for hidden files</source>
@@ -1529,6 +1580,11 @@ Modified: %2</source>
         <source>Smaller than:</source>
         <translation></translation>
     </message>
+    <message>
+        <location filename="../filesearch.ui" line="122"/>
+        <source>Search in subdirectories</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../filesearch.ui" line="370"/>
         <source>Last Modified Time:</source>
