@@ -31,7 +31,7 @@
 
 #include <pwd.h>
 #include <grp.h>
-#include <stdlib.h>
+#include <cstdlib>
 #include <glib.h>
 
 namespace Fm {
@@ -70,9 +70,9 @@ std::pair<Fm::FilePathList, bool> parseClipboardData(const QMimeData& data) {
     bool isCut = false;
     Fm::FilePathList paths;
 
-    if(data.hasFormat("x-special/gnome-copied-files")) {
+    if(data.hasFormat(QStringLiteral("x-special/gnome-copied-files"))) {
         // Gnome, LXDE, and XFCE
-        QByteArray gnomeData = data.data("x-special/gnome-copied-files");
+        QByteArray gnomeData = data.data(QStringLiteral("x-special/gnome-copied-files"));
         char* pdata = gnomeData.data();
         char* eol = strchr(pdata, '\n');
 
@@ -117,16 +117,13 @@ void pasteFilesFromClipboard(const Fm::FilePath& destPath, QWidget* parent) {
 void copyFilesToClipboard(const Fm::FilePathList& files) {
     QClipboard* clipboard = QApplication::clipboard();
     QMimeData* data = new QMimeData();
-    QByteArray ba;
     auto urilist = pathListToUriList(files);
 
-    // Add current pid to trace cut/copy operations to current app
-    data->setData(QStringLiteral("text/x-libfmqt-pid"), ba.setNum(QCoreApplication::applicationPid()));
     // Gnome, LXDE, and XFCE
     // Note: the standard text/urilist format uses CRLF for line breaks, but gnome format uses LF only
-    data->setData("x-special/gnome-copied-files", QByteArray("copy\n") + urilist.replace("\r\n", "\n"));
+    data->setData(QStringLiteral("x-special/gnome-copied-files"), QByteArray("copy\n") + urilist.replace("\r\n", "\n"));
     // The KDE way
-    data->setData("text/uri-list", urilist);
+    data->setData(QStringLiteral("text/uri-list"), urilist);
     // data->setData(QStringLiteral("application/x-kde-cutselection"), QByteArrayLiteral("0"));
     clipboard->setMimeData(data);
 }
@@ -134,42 +131,38 @@ void copyFilesToClipboard(const Fm::FilePathList& files) {
 void cutFilesToClipboard(const Fm::FilePathList& files) {
     QClipboard* clipboard = QApplication::clipboard();
     QMimeData* data = new QMimeData();
-    QByteArray ba;
     auto urilist = pathListToUriList(files);
 
-    // Add current pid to trace cut/copy operations to current app
-    data->setData(QStringLiteral("text/x-libfmqt-pid"), ba.setNum(QCoreApplication::applicationPid()));
     // Gnome, LXDE, and XFCE
     // Note: the standard text/urilist format uses CRLF for line breaks, but gnome format uses LF only
-    data->setData("x-special/gnome-copied-files", QByteArray("cut\n") + urilist.replace("\r\n", "\n"));
+    data->setData(QStringLiteral("x-special/gnome-copied-files"), QByteArray("cut\n") + urilist.replace("\r\n", "\n"));
     // The KDE way
-    data->setData("text/uri-list", urilist);
+    data->setData(QStringLiteral("text/uri-list"), urilist);
     data->setData(QStringLiteral("application/x-kde-cutselection"), QByteArrayLiteral("1"));
     clipboard->setMimeData(data);
 }
 
-bool isCurrentPidClipboardData(const QMimeData& data) {
-    QByteArray clip_pid = data.data(QStringLiteral("text/x-libfmqt-pid"));
-    QByteArray curr_pid;
-    curr_pid.setNum(QCoreApplication::applicationPid());
-
-    return !clip_pid.isEmpty() && clip_pid == curr_pid;
-}
-
 bool changeFileName(const Fm::FilePath& filePath, const QString& newName, QWidget* parent, bool showMessage) {
-    auto dest = filePath.parent().child(newName.toLocal8Bit().constData());
+    // NOTE: g_file_set_display_name() is used instead of g_file_move() because,
+    // otherwise, renaming will not be possible in places like google-drive:///.
     Fm::GErrorPtr err;
-    if(!g_file_move(filePath.gfile().get(), dest.gfile().get(),
-                    GFileCopyFlags(G_FILE_COPY_ALL_METADATA |
-                                   G_FILE_COPY_NO_FALLBACK_FOR_MOVE |
-                                   G_FILE_COPY_NOFOLLOW_SYMLINKS),
-                    nullptr, /* make this cancellable later. */
-                    nullptr, nullptr, &err)) {
+    GFilePtr gfile{g_file_set_display_name(filePath.gfile().get(),
+                                            newName.toLocal8Bit().constData(),
+                                            nullptr, /* make this cancellable later. */
+                                            &err)};
+    if(gfile == nullptr) {
         if (showMessage){
             QMessageBox::critical(parent ? parent->window() : nullptr, QObject::tr("Error"), err.message());
         }
         return false;
     }
+
+    // reload the containing folder if it is in use but does not have a file monitor
+    auto folder = Fm::Folder::findByPath(filePath.parent());
+    if(folder && folder->isValid() && folder->isLoaded() && !folder->hasFileMonitor()) {
+        folder->reload();
+    }
+
     return true;
 }
 
@@ -177,8 +170,11 @@ bool renameFile(std::shared_ptr<const Fm::FileInfo> file, QWidget* parent) {
     FilenameDialog dlg(parent ? parent->window() : nullptr);
     dlg.setWindowTitle(QObject::tr("Rename File"));
     dlg.setLabelText(QObject::tr("Please enter a new name:"));
-    // FIXME: what's the best way to handle non-UTF8 filename encoding here?
-    auto old_name = QString::fromStdString(file->name());
+    // NOTE: "Edit name" seems the best way to handle non-UTF8 filename encoding.
+    auto old_name = QString::fromUtf8(g_file_info_get_edit_name(file->gFileInfo().get()));
+    if(old_name.isEmpty()) {
+        old_name = QString::fromStdString(file->name());
+    }
     dlg.setTextValue(old_name);
 
     if(file->isDir()) { // select filename extension for directories
@@ -217,7 +213,7 @@ void createFileOrFolder(CreateFileType type, FilePath parentDir, const TemplateI
 
     case CreateWithTemplate: {
         auto mime = templ->mimeType();
-        prompt = QObject::tr("Enter a name for the new %1:").arg(mime->desc());
+        prompt = QObject::tr("Enter a name for the new %1:").arg(QString::fromUtf8(mime->desc()));
         defaultNewName = QString::fromStdString(templ->name());
     }
     break;
@@ -263,6 +259,12 @@ _retry:
 
         QMessageBox::critical(parent ? parent->window() : nullptr, QObject::tr("Error"), err.message());
     }
+    else { // reload the containing folder if it is in use but does not have a file monitor
+        auto folder = Fm::Folder::findByPath(parentDir);
+        if(folder && folder->isValid() && folder->isLoaded() && !folder->hasFileMonitor()) {
+            folder->reload();
+        }
+    }
 }
 
 uid_t uidFromName(QString name) {
@@ -274,7 +276,7 @@ uid_t uidFromName(QString name) {
         ret = uid_t(name.toUInt());
     }
     else {
-        struct passwd* pw = getpwnam(name.toLatin1());
+        struct passwd* pw = getpwnam(name.toLatin1().constData());
         // FIXME: use getpwnam_r instead later to make it reentrant
         ret = pw ? pw->pw_uid : INVALID_UID;
     }
@@ -287,7 +289,7 @@ QString uidToName(uid_t uid) {
     struct passwd* pw = getpwuid(uid);
 
     if(pw) {
-        ret = pw->pw_name;
+        ret = QString::fromUtf8(pw->pw_name);
     }
     else {
         ret = QString::number(uid);
@@ -306,7 +308,7 @@ gid_t gidFromName(QString name) {
     }
     else {
         // FIXME: use getgrnam_r instead later to make it reentrant
-        struct group* grp = getgrnam(name.toLatin1());
+        struct group* grp = getgrnam(name.toLatin1().constData());
         ret = grp ? grp->gr_gid : INVALID_GID;
     }
 
@@ -318,7 +320,7 @@ QString gidToName(gid_t gid) {
     struct group* grp = getgrgid(gid);
 
     if(grp) {
-        ret = grp->gr_name;
+        ret = QString::fromUtf8(grp->gr_name);
     }
     else {
         ret = QString::number(gid);
@@ -368,7 +370,7 @@ bool uriExists(const char* uri) {
 
 QString formatFileSize(uint64_t size, bool useSI) {
     Fm::CStrPtr str{g_format_size_full(size, useSI ? G_FORMAT_SIZE_DEFAULT : G_FORMAT_SIZE_IEC_UNITS)};
-    return QString(str.get());
+    return QString(QString::fromUtf8(str.get()));
 }
 
 } // namespace Fm
